#include <stdio.h>
#include "ISO10163-SR-1-types.h"


# line 3 "SR.py"

#include "SR.h"

extern caddr_t _ZptrtabISO10163_SR_1[];	/* forward decl */

#define OFFSET(t,f)	((int ) &(((t *)0)->f))


#define AOFFSET(t,f)	((int ) (((t *)0)->f))

static ptpe et_SR_APDUISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[0] },
	{ SCHOICE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[0] },
	{ SCTRL, OFFSET(struct _SR_APDU , offset), 0, 0, (char **)&_ZptrtabISO10163_SR_1[0] },
	{ ETAG, 0, 20, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[1] },
	{ ANY, OFFSET(struct _SR_APDU , pe), -1, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[1] },
	{ ETAG, 0, 21, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[2] },
	{ ANY, OFFSET(struct _SR_APDU , pe), -1, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[2] },
	{ ETAG, 0, 22, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[3] },
	{ ANY, OFFSET(struct _SR_APDU , pe), -1, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[3] },
	{ ETAG, 0, 23, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[4] },
	{ ANY, OFFSET(struct _SR_APDU , pe), -1, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[4] },
	{ ETAG, 0, 24, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[5] },
	{ ANY, OFFSET(struct _SR_APDU , pe), -1, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[5] },
	{ ETAG, 0, 25, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[6] },
	{ ANY, OFFSET(struct _SR_APDU , pe), -1, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[6] },
	{ ETAG, 0, 26, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[7] },
	{ ANY, OFFSET(struct _SR_APDU , pe), -1, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[7] },
	{ ETAG, 0, 27, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[8] },
	{ ANY, OFFSET(struct _SR_APDU , pe), -1, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[8] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[0] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[0] }
	};

static ptpe et_XSR_APDUISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[9] },
	{ SCHOICE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[9] },
	{ SCTRL, OFFSET(struct type_ISO10163__SR__1_XSR__APDU, offset), 0, 0, (char **)&_ZptrtabISO10163_SR_1[9] },
	{ IMP_OBJ, 0, 20, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[1] },
	{ OBJECT, OFFSET(struct type_ISO10163__SR__1_XSR__APDU, un.initialiseRequest), _ZInitialiseRequestISO10163_SR_1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[1] },
	{ IMP_OBJ, 0, 21, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[2] },
	{ OBJECT, OFFSET(struct type_ISO10163__SR__1_XSR__APDU, un.initialiseResponse), _ZInitialiseResponseISO10163_SR_1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[2] },
	{ IMP_OBJ, 0, 22, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[3] },
	{ OBJECT, OFFSET(struct type_ISO10163__SR__1_XSR__APDU, un.searchRequest), _ZSearchRequestISO10163_SR_1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[3] },
	{ IMP_OBJ, 0, 23, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[4] },
	{ OBJECT, OFFSET(struct type_ISO10163__SR__1_XSR__APDU, un.searchResponse), _ZSearchResponseISO10163_SR_1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[4] },
	{ IMP_OBJ, 0, 24, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[5] },
	{ OBJECT, OFFSET(struct type_ISO10163__SR__1_XSR__APDU, un.presentRequest), _ZPresentRequestISO10163_SR_1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[5] },
	{ IMP_OBJ, 0, 25, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[6] },
	{ OBJECT, OFFSET(struct type_ISO10163__SR__1_XSR__APDU, un.presentResponse), _ZPresentResponseISO10163_SR_1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[6] },
	{ IMP_OBJ, 0, 26, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[7] },
	{ OBJECT, OFFSET(struct type_ISO10163__SR__1_XSR__APDU, un.deleteResultSetRequest), _ZDeleteResultSetRequestISO10163_SR_1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[7] },
	{ IMP_OBJ, 0, 27, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[8] },
	{ OBJECT, OFFSET(struct type_ISO10163__SR__1_XSR__APDU, un.deleteResultSetResponse), _ZDeleteResultSetResponseISO10163_SR_1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[8] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[9] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[9] }
	};

static ptpe et_ObjectDescriptorISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[10] },
	{ ETAG, 0, 7, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[10] },
	{ SOCTETSTRING, 0, 4, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[10] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[10] }
	};

static ptpe et_THISEXTERNALISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[11] },
	{ SSEQ_START, 0, 8, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[11] },
	{ OPTL, OFFSET(struct Extern , optionals), 0, 0, (char **)&_ZptrtabISO10163_SR_1[11] },
	{ OBJID, OFFSET(struct Extern , directReference), 6, FL_UNIVERSAL|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[12] },
	{ INTEGER, OFFSET(struct Extern , indirectReference), 2, FL_UNIVERSAL|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[13] },
	{ ETAG, 0, 7, FL_UNIVERSAL|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[10] },
	{ OCTET_PTR, OFFSET(struct Extern , dataValueDescriptor.value), 4, FL_UNIVERSAL|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[10] },
	{ OCTET_LEN, OFFSET(struct Extern , dataValueDescriptor.len), 4, FL_UNIVERSAL|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[10] },
	{ SCHOICE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[11] },
	{ SCTRL, OFFSET(struct Extern , offset), 0, 0, (char **)&_ZptrtabISO10163_SR_1[11] },
	{ ETAG, 0, 0, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[14] },
	{ ANY, OFFSET(struct Extern , singleASN1Type), -1, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[14] },
	{ OCTET_PTR, OFFSET(struct Extern , octetAligned.value), 1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[15] },
	{ OCTET_LEN, OFFSET(struct Extern , octetAligned.len), 1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[15] },
	{ BITSTR_PTR, OFFSET(struct Extern , arbitrary.value), 2, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[16] },
	{ BITSTR_LEN, OFFSET(struct Extern , arbitrary.len), 2, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[16] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[11] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[11] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[11] }
	};

static ptpe et_InitialiseRequestISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[17] },
	{ SSEQ_START, 0, 16, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[17] },
	{ OBJECT, OFFSET(struct _InitialiseRequest , referenceId), _ZReferenceIdISO10163_SR_1, FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[18] },
	{ BITSTRING, OFFSET(struct _InitialiseRequest , protocolVersion), 3, FL_CONTEXT, NULLVP },
	{ BITSTRING, OFFSET(struct _InitialiseRequest , options), 4, FL_CONTEXT, NULLVP },
	{ INTEGER, OFFSET(struct _InitialiseRequest , preferredMessageSize), 5, FL_CONTEXT, NULLVP },
	{ INTEGER, OFFSET(struct _InitialiseRequest , maximumMessageSize), 6, FL_CONTEXT, NULLVP },
	{ ETAG, 0, 7, FL_CONTEXT|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[19] },
	{ ANY, OFFSET(struct _InitialiseRequest , authentication), -1, FL_UNIVERSAL|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[19] },
	{ T_STRING, OFFSET(struct _InitialiseRequest , implementationId), 110, FL_CONTEXT|FL_OPTIONAL, NULLVP },
	{ T_STRING, OFFSET(struct _InitialiseRequest , implementationName), 111, FL_CONTEXT|FL_OPTIONAL, NULLVP },
	{ T_STRING, OFFSET(struct _InitialiseRequest , implementationVersion), 112, FL_CONTEXT|FL_OPTIONAL, NULLVP },
	{ OBJECT, OFFSET(struct _InitialiseRequest , userInformationField), _ZUserInformationFieldISO10163_SR_1, FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[20] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[17] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[17] }
	};

static ptpe et_InitialiseResponseISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[21] },
	{ SSEQ_START, 0, 16, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[21] },
	{ OBJECT, OFFSET(struct _InitialiseResponse , referenceId), _ZReferenceIdISO10163_SR_1, FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[18] },
	{ BITSTRING, OFFSET(struct _InitialiseResponse , protocolVersion), 3, FL_CONTEXT, NULLVP },
	{ BITSTRING, OFFSET(struct _InitialiseResponse , options), 4, FL_CONTEXT, NULLVP },
	{ INTEGER, OFFSET(struct _InitialiseResponse , preferredMessageSize), 5, FL_CONTEXT, NULLVP },
	{ INTEGER, OFFSET(struct _InitialiseResponse , maximumMessageSize), 6, FL_CONTEXT, NULLVP },
	{ BOOLEAN, OFFSET(struct _InitialiseResponse , initializationStatus), 12, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[22] },
	{ T_STRING, OFFSET(struct _InitialiseResponse , implementationId), 110, FL_CONTEXT|FL_OPTIONAL, NULLVP },
	{ T_STRING, OFFSET(struct _InitialiseResponse , implementationName), 111, FL_CONTEXT|FL_OPTIONAL, NULLVP },
	{ T_STRING, OFFSET(struct _InitialiseResponse , implementationVersion), 112, FL_CONTEXT|FL_OPTIONAL, NULLVP },
	{ OBJECT, OFFSET(struct _InitialiseResponse , userInformationField), _ZUserInformationFieldISO10163_SR_1, FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[20] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[21] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[21] }
	};

static ptpe et_ProtocolVersionISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[23] },
	{ SBITSTRING, 0, 3, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[23] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[23] }
	};

static ptpe et_OptionsISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[24] },
	{ SBITSTRING, 0, 4, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[24] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[24] }
	};

static ptpe et_PreferredMessageSizeISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[25] },
	{ INTEGER, OFFSET(struct type_ISO10163__SR__1_PreferredMessageSize, parm), 5, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[25] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[25] }
	};

static ptpe et_MaximumMessageSizeISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[26] },
	{ INTEGER, OFFSET(struct type_ISO10163__SR__1_MaximumMessageSize, parm), 6, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[26] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[26] }
	};

static ptpe et_ImplementationIdISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[27] },
	{ SOCTETSTRING, 0, 110, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[27] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[27] }
	};

static ptpe et_ImplementationNameISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[28] },
	{ SOCTETSTRING, 0, 111, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[28] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[28] }
	};

static ptpe et_ImplementationVersionISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[29] },
	{ SOCTETSTRING, 0, 112, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[29] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[29] }
	};

static ptpe et_UserInformationFieldISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[30] },
	{ ETAG, 0, 11, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[30] },
	{ SOBJECT, 0, _ZTHISEXTERNALISO10163_SR_1, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[30] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[30] }
	};

static ptpe et_AuthenticationISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[31] },
	{ SSEQ_START, 0, 16, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[31] },
	{ OCTET_PTR, OFFSET(struct _Authentication , user.value), 26, FL_UNIVERSAL, NULLVP },
	{ OCTET_LEN, OFFSET(struct _Authentication , user.len), 26, FL_UNIVERSAL, NULLVP },
	{ OCTET_PTR, OFFSET(struct _Authentication , password.value), 26, FL_UNIVERSAL, NULLVP },
	{ OCTET_LEN, OFFSET(struct _Authentication , password.len), 26, FL_UNIVERSAL, NULLVP },
	{ OCTET_PTR, OFFSET(struct _Authentication , account.value), 26, FL_UNIVERSAL, NULLVP },
	{ OCTET_LEN, OFFSET(struct _Authentication , password.len), 26, FL_UNIVERSAL, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[31] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[31] }
	};

static ptpe et_SearchRequestISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[32] },
	{ SSEQ_START, 0, 16, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[32] },
	{ OBJECT, OFFSET(struct _SearchRequest , referenceId), _ZReferenceIdISO10163_SR_1, FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[18] },
	{ INTEGER, OFFSET(struct _SearchRequest , smallSetUpperBound), 13, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[33] },
	{ INTEGER, OFFSET(struct _SearchRequest , largeSetLowerBound), 14, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[34] },
	{ INTEGER, OFFSET(struct _SearchRequest , mediumSetPresentNumber), 15, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[35] },
	{ BOOLEAN, OFFSET(struct _SearchRequest , replaceIndicator), 16, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[36] },
	{ T_STRING, OFFSET(struct _SearchRequest , proposedResultSetId), 17, FL_CONTEXT, NULLVP },
	{ SEQOF_START, OFFSET(struct _SearchRequest , databaseId), 18, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[37] },
	{ T_STRING, OFFSET(struct _SeqOf_DatabaseName , name), 105, FL_CONTEXT, NULLVP },
	{ PE_END, OFFSET(struct _SeqOf_DatabaseName , next), 0, 0, (char **)&_ZptrtabISO10163_SR_1[37] },
	{ ETAG, 0, 100, FL_CONTEXT|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[38] },
	{ OBJECT, OFFSET(struct _SearchRequest , smallSetRecordComposition), _ZRecordCompositionISO10163_SR_1, FL_UNIVERSAL|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[38] },
	{ ETAG, 0, 101, FL_CONTEXT|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[39] },
	{ OBJECT, OFFSET(struct _SearchRequest , mediumSetRecordComposition), _ZRecordCompositionISO10163_SR_1, FL_UNIVERSAL|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[39] },
	{ OBJID, OFFSET(struct _SearchRequest , preferredRecordSyntax), 104, FL_CONTEXT|FL_OPTIONAL, NULLVP },
	{ ETAG, 0, 21, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[40] },
	{ OBJECT, OFFSET(struct _SearchRequest , query), _ZQueryISO10163_SR_1, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[40] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[32] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[32] }
	};

static ptpe et_QueryISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[41] },
	{ SCHOICE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[41] },
	{ SCTRL, OFFSET(struct _Query , offset), 0, 0, (char **)&_ZptrtabISO10163_SR_1[41] },
	{ ETAG, 0, 0, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[42] },
	{ ANY, OFFSET(struct _Query , privateQuery), -1, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[42] },
	{ IMP_OBJ, 0, 1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[43] },
	{ OBJECT, OFFSET(struct _Query , rpnQuery), _ZRPNQueryISO10163_SR_1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[43] },
	{ ETAG, 0, 2, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[44] },
	{ OCTET_PTR, OFFSET(struct _Query , iso8777Query.value), 4, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[44] },
	{ OCTET_LEN, OFFSET(struct _Query , iso8777Query.len), 4, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[44] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[41] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[41] }
	};

static ptpe et_RPNQueryISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[45] },
	{ SSEQ_START, 0, 16, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[45] },
	{ OBJID, OFFSET(struct _RPNQuery , attributeSetId), 6, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[46] },
	{ OBJECT, OFFSET(struct _RPNQuery , rpnStructure), _ZRPNStructureISO10163_SR_1, 0, (char **)&_ZptrtabISO10163_SR_1[45] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[45] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[45] }
	};

static ptpe et_RPNStructureISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[47] },
	{ SCHOICE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[47] },
	{ SCTRL, OFFSET(struct _RPNStructure , offset), 0, 0, (char **)&_ZptrtabISO10163_SR_1[47] },
	{ ETAG, 0, 0, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[47] },
	{ OBJECT, OFFSET(struct _RPNStructure , operand), _ZOperandISO10163_SR_1, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[47] },
	{ SSEQ_START, 0, 1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[47] },
	{ OBJECT, OFFSET(struct _RPNStructure , compound.rpnStructure1), _ZRPNStructureISO10163_SR_1, 0, (char **)&_ZptrtabISO10163_SR_1[47] },
	{ OBJECT, OFFSET(struct _RPNStructure , compound.rpnStructure2), _ZRPNStructureISO10163_SR_1, 0, (char **)&_ZptrtabISO10163_SR_1[47] },
	{ OBJECT, OFFSET(struct _RPNStructure , compound.operator), _ZOperatorISO10163_SR_1, 0, (char **)&_ZptrtabISO10163_SR_1[47] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[47] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[47] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[47] }
	};

static ptpe et_OperandISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[48] },
	{ SCHOICE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[48] },
	{ SCTRL, OFFSET(struct _Operand , offset), 0, 0, (char **)&_ZptrtabISO10163_SR_1[48] },
	{ OBJECT, OFFSET(struct _Operand , attributesPlusTerm), _ZAttributesPlusTermISO10163_SR_1, 0, (char **)&_ZptrtabISO10163_SR_1[48] },
	{ T_STRING, OFFSET(struct _Operand , resultSetId), 31, FL_CONTEXT, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[48] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[48] }
	};

static ptpe et_AttributesPlusTermISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[49] },
	{ SSEQ_START, 0, 102, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[49] },
	{ OBJECT, OFFSET(struct _AttributesPlusTerm , attributeList), _ZAttributeListISO10163_SR_1, 0, (char **)&_ZptrtabISO10163_SR_1[49] },
	{ OBJECT, OFFSET(struct _AttributesPlusTerm , term), _ZTermISO10163_SR_1, 0, (char **)&_ZptrtabISO10163_SR_1[49] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[49] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[49] }
	};

static ptpe et_AttributeListISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[50] },
	{ SSEQOF_START, 0, 44, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[50] },
	{ SOBJECT, 0, _ZAttributeElementISO10163_SR_1, 0, (char **)&_ZptrtabISO10163_SR_1[50] },
	{ PE_END, OFFSET(struct _AttributeList , next), 0, 0, (char **)&_ZptrtabISO10163_SR_1[50] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[50] }
	};

static ptpe et_TermISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[51] },
	{ OCTET_PTR, OFFSET(struct octetString , value), 45, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[51] },
	{ OCTET_LEN, OFFSET(struct octetString , len), 45, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[51] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[51] }
	};

static ptpe et_OperatorISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[52] },
	{ ETAG, 0, 46, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[52] },
	{ SCHOICE_START, 0, 0, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[52] },
	{ SCTRL, OFFSET(struct _Operator , offset), 0, 0, (char **)&_ZptrtabISO10163_SR_1[52] },
	{ T_NULL, 0, 0, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[53] },
	{ T_NULL, 0, 1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[54] },
	{ T_NULL, 0, 2, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[55] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[52] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[52] }
	};

static ptpe et_AttributeElementISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[56] },
	{ SSEQ_START, 0, 16, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[56] },
	{ INTEGER, OFFSET(struct _AttributeElement , attributeType), 120, FL_CONTEXT, NULLVP },
	{ INTEGER, OFFSET(struct _AttributeElement , attributeValue), 121, FL_CONTEXT, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[56] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[56] }
	};

static ptpe et_AttributeTypeISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[57] },
	{ INTEGER, OFFSET(struct type_ISO10163__SR__1_AttributeType, parm), 120, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[57] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[57] }
	};

static ptpe et_AttributeValueISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[58] },
	{ INTEGER, OFFSET(struct type_ISO10163__SR__1_AttributeValue, parm), 121, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[58] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[58] }
	};

static ptpe et_SearchResponseISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[59] },
	{ SSEQ_START, 0, 16, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[59] },
	{ OPTL, OFFSET(struct _SearchResponse , optionals), 0, 0, (char **)&_ZptrtabISO10163_SR_1[59] },
	{ OBJECT, OFFSET(struct _SearchResponse , referenceId), _ZReferenceIdISO10163_SR_1, FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[18] },
	{ INTEGER, OFFSET(struct _SearchResponse , numberOfRecordsFound), 23, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[60] },
	{ INTEGER, OFFSET(struct _SearchResponse , numberOfRecordsReturned), 24, FL_CONTEXT, NULLVP },
	{ INTEGER, OFFSET(struct _SearchResponse , nextResultSetPosition), 25, FL_CONTEXT, NULLVP },
	{ BOOLEAN, OFFSET(struct _SearchResponse , searchStatus), 22, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[61] },
	{ INTEGER, OFFSET(struct _SearchResponse , resultSetStatus), 26, FL_CONTEXT|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[62] },
	{ INTEGER, OFFSET(struct _SearchResponse , presentStatus), 27, FL_CONTEXT|FL_OPTIONAL, NULLVP },
	{ OBJECT, OFFSET(struct _SearchResponse , records), _ZRecordsISO10163_SR_1, FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[63] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[59] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[59] }
	};

static ptpe et_PresentRequestISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[64] },
	{ SSEQ_START, 0, 16, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[64] },
	{ OBJECT, OFFSET(struct _PresentRequest , referenceId), _ZReferenceIdISO10163_SR_1, FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[18] },
	{ T_STRING, OFFSET(struct _PresentRequest , resultSetId), 31, FL_CONTEXT, NULLVP },
	{ INTEGER, OFFSET(struct _PresentRequest , resultSetStartPoint), 30, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[65] },
	{ INTEGER, OFFSET(struct _PresentRequest , numberOfRecordsRequested), 29, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[66] },
	{ OBJECT, OFFSET(struct _PresentRequest , recordComposition), _ZRecordCompositionISO10163_SR_1, FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[64] },
	{ OBJID, OFFSET(struct _PresentRequest , preferredRecordSyntax), 104, FL_CONTEXT|FL_OPTIONAL, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[64] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[64] }
	};

static ptpe et_PresentResponseISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[67] },
	{ SSEQ_START, 0, 16, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[67] },
	{ OBJECT, OFFSET(struct type_ISO10163__SR__1_PresentResponse, referenceId), _ZReferenceIdISO10163_SR_1, FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[18] },
	{ INTEGER, OFFSET(struct type_ISO10163__SR__1_PresentResponse, numberOfRecordsReturned), 24, FL_CONTEXT, NULLVP },
	{ INTEGER, OFFSET(struct type_ISO10163__SR__1_PresentResponse, nextResultSetPosition), 25, FL_CONTEXT, NULLVP },
	{ INTEGER, OFFSET(struct type_ISO10163__SR__1_PresentResponse, presentStatus), 27, FL_CONTEXT, NULLVP },
	{ OBJECT, OFFSET(struct type_ISO10163__SR__1_PresentResponse, records), _ZRecordsISO10163_SR_1, FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[63] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[67] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[67] }
	};

static ptpe et_RecordsISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[68] },
	{ SCHOICE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[68] },
	{ SCTRL, OFFSET(struct _Records , offset), 0, 0, (char **)&_ZptrtabISO10163_SR_1[68] },
	{ SEQOF_START, OFFSET(struct _Records , databaseOrSurDiagnostics), 28, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[69] },
	{ SOBJECT, 0, _ZNamePlusRecordISO10163_SR_1, 0, (char **)&_ZptrtabISO10163_SR_1[68] },
	{ PE_END, OFFSET(struct _NamePlusRecord , next), 0, 0, (char **)&_ZptrtabISO10163_SR_1[69] },
	{ IMP_OBJ, 0, 130, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[70] },
	{ OBJECT, OFFSET(struct _Records , nonSurrogateDiagnostic), _ZDiagRecISO10163_SR_1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[70] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[68] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[68] }
	};

static ptpe et_NamePlusRecordISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[71] },
	{ SSEQ_START, 0, 16, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[71] },
	{ T_STRING, OFFSET(struct _NamePlusRecord , databaseName), 0, FL_CONTEXT|FL_OPTIONAL, NULLVP },
	{ ETAG, 0, 1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[71] },
	{ SCHOICE_START, 0, 0, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[71] },
	{ SCTRL, OFFSET(struct _NamePlusRecord , offset), 0, 0, (char **)&_ZptrtabISO10163_SR_1[71] },
	{ ETAG, 0, 1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[72] },
	{ OBJECT, OFFSET(struct _NamePlusRecord , databaseRecord), _ZDatabaseRecordISO10163_SR_1, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[72] },
	{ ETAG, 0, 2, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[73] },
	{ OBJECT, OFFSET(struct _NamePlusRecord , surrogateDiagnostic), _ZDiagRecISO10163_SR_1, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[73] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[71] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[71] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[71] }
	};

static ptpe et_DatabaseRecordISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[74] },
	{ SOBJECT, 0, _ZTHISEXTERNALISO10163_SR_1, 0, (char **)&_ZptrtabISO10163_SR_1[74] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[74] }
	};

static ptpe et_DiagRecISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[75] },
	{ SSEQ_START, 0, 16, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[75] },
	{ OBJID, OFFSET(struct _DiagRec , diagnosticSetId), 6, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[76] },
	{ INTEGER, OFFSET(struct _DiagRec , condition), 2, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[77] },
	{ T_STRING, OFFSET(struct _DiagRec , addinfo), 26, FL_UNIVERSAL, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[75] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[75] }
	};

static ptpe et_RecordCompositionISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[78] },
	{ ETAG, 0, 19, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[78] },
	{ SCHOICE_START, 0, 0, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[78] },
	{ SCTRL, OFFSET(struct _RecordComposition , offset), 0, 0, (char **)&_ZptrtabISO10163_SR_1[78] },
	{ T_STRING, OFFSET(struct _RecordComposition , generic), 0, FL_CONTEXT, NULLVP },
	{ SEQOF_START, OFFSET(struct _RecordComposition , databaseSpecific), 1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[79] },
	{ SSEQ_START, 0, 16, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[78] },
	{ T_STRING, OFFSET(struct _RCDatabaseSpecific , databaseName), 105, FL_CONTEXT, NULLVP },
	{ T_STRING, OFFSET(struct _RCDatabaseSpecific , recordCompositionId), 103, FL_CONTEXT, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[78] },
	{ PE_END, OFFSET(struct _RCDatabaseSpecific , next), 0, 0, (char **)&_ZptrtabISO10163_SR_1[79] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[78] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[78] }
	};

static ptpe et_RecordCompositionIdISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[80] },
	{ SOCTETSTRING, 0, 103, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[80] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[80] }
	};

static ptpe et_NumberOfRecordsReturnedISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[81] },
	{ INTEGER, OFFSET(struct type_ISO10163__SR__1_NumberOfRecordsReturned, parm), 24, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[81] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[81] }
	};

static ptpe et_NextResultSetPositionISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[82] },
	{ INTEGER, OFFSET(struct type_ISO10163__SR__1_NextResultSetPosition, parm), 25, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[82] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[82] }
	};

static ptpe et_PresentStatusISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[83] },
	{ INTEGER, OFFSET(struct type_ISO10163__SR__1_PresentStatus, parm), 27, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[83] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[83] }
	};

static ptpe et_PreferredRecordSyntaxISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[84] },
	{ SOBJID, 0, 104, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[84] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[84] }
	};

static ptpe et_DeleteResultSetRequestISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[85] },
	{ SSEQ_START, 0, 16, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[85] },
	{ OBJECT, OFFSET(struct _DeleteResultSetRequest , referenceId), _ZReferenceIdISO10163_SR_1, FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[18] },
	{ INTEGER, OFFSET(struct _DeleteResultSetRequest , deleteSetFunction), 32, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[86] },
	{ SEQOF_START, OFFSET(struct _DeleteResultSetRequest , resultSetList), 16, FL_UNIVERSAL|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[87] },
	{ T_STRING, OFFSET(struct _ResultSetList , resultSetId), 31, FL_CONTEXT, NULLVP },
	{ PE_END, OFFSET(struct _ResultSetList , next), 0, 0, (char **)&_ZptrtabISO10163_SR_1[87] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[85] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[85] }
	};

static ptpe et_DeleteResultSetResponseISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[88] },
	{ SSEQ_START, 0, 16, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[88] },
	{ OPTL, OFFSET(struct _DeleteResultSetResponse , optionals), 0, 0, (char **)&_ZptrtabISO10163_SR_1[88] },
	{ OBJECT, OFFSET(struct _DeleteResultSetResponse , referenceId), _ZReferenceIdISO10163_SR_1, FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[18] },
	{ INTEGER, OFFSET(struct _DeleteResultSetResponse , deleteOperationStatus), 0, FL_CONTEXT, NULLVP },
	{ IMP_OBJ, 0, 1, FL_CONTEXT|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[89] },
	{ OBJECT, OFFSET(struct _DeleteResultSetResponse , deleteListStatuses), _ZListStatusesISO10163_SR_1, FL_CONTEXT|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[89] },
	{ INTEGER, OFFSET(struct _DeleteResultSetResponse , numberNotDeleted), 34, FL_CONTEXT|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[90] },
	{ IMP_OBJ, 0, 35, FL_CONTEXT|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[91] },
	{ OBJECT, OFFSET(struct _DeleteResultSetResponse , bulkStatuses), _ZListStatusesISO10163_SR_1, FL_CONTEXT|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[91] },
	{ T_STRING, OFFSET(struct _DeleteResultSetResponse , deleteMessage), 36, FL_CONTEXT|FL_OPTIONAL, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[88] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[88] }
	};

static ptpe et_ListStatusesISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[92] },
	{ SSEQOF_START, 0, 16, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[92] },
	{ SSEQ_START, 0, 16, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[92] },
	{ T_STRING, OFFSET(struct _ListStatuses , resultSetId), 31, FL_CONTEXT, NULLVP },
	{ INTEGER, OFFSET(struct _ListStatuses , deleteSetStatus), 33, FL_CONTEXT, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[92] },
	{ PE_END, OFFSET(struct _ListStatuses , next), 0, 0, (char **)&_ZptrtabISO10163_SR_1[92] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[92] }
	};

static ptpe et_DeleteSetStatusISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[93] },
	{ INTEGER, OFFSET(struct type_ISO10163__SR__1_DeleteSetStatus, parm), 33, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[93] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[93] }
	};

static ptpe et_ReferenceIdISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[94] },
	{ OCTET_PTR, OFFSET(struct octetString , value), 2, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[94] },
	{ OCTET_LEN, OFFSET(struct octetString , len), 2, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[94] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[94] }
	};

static ptpe et_DatabaseNameISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[95] },
	{ SOCTETSTRING, 0, 105, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[95] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[95] }
	};

static ptpe et_ResultSetIdISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[96] },
	{ SOCTETSTRING, 0, 31, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[96] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[96] }
	};

static ptpe dt_SR_APDUISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[0] },
	{ SCHOICE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[0] },
	{ MEMALLOC, 0, sizeof (struct _SR_APDU ), 0, (char **)&_ZptrtabISO10163_SR_1[0] },
	{ SCTRL, OFFSET(struct _SR_APDU , offset), 0, 0, (char **)&_ZptrtabISO10163_SR_1[0] },
	{ ETAG, 0, 20, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[1] },
	{ ANY, OFFSET(struct _SR_APDU , pe), -1, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[1] },
	{ ETAG, 0, 21, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[2] },
	{ ANY, OFFSET(struct _SR_APDU , pe), -1, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[2] },
	{ ETAG, 0, 22, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[3] },
	{ ANY, OFFSET(struct _SR_APDU , pe), -1, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[3] },
	{ ETAG, 0, 23, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[4] },
	{ ANY, OFFSET(struct _SR_APDU , pe), -1, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[4] },
	{ ETAG, 0, 24, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[5] },
	{ ANY, OFFSET(struct _SR_APDU , pe), -1, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[5] },
	{ ETAG, 0, 25, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[6] },
	{ ANY, OFFSET(struct _SR_APDU , pe), -1, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[6] },
	{ ETAG, 0, 26, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[7] },
	{ ANY, OFFSET(struct _SR_APDU , pe), -1, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[7] },
	{ ETAG, 0, 27, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[8] },
	{ ANY, OFFSET(struct _SR_APDU , pe), -1, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[8] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[0] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[0] }
	};

static ptpe dt_XSR_APDUISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[9] },
	{ SCHOICE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[9] },
	{ MEMALLOC, 0, sizeof (struct type_ISO10163__SR__1_XSR__APDU), 0, (char **)&_ZptrtabISO10163_SR_1[9] },
	{ SCTRL, OFFSET(struct type_ISO10163__SR__1_XSR__APDU, offset), 0, 0, (char **)&_ZptrtabISO10163_SR_1[9] },
	{ IMP_OBJ, 0, 20, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[1] },
	{ OBJECT, OFFSET(struct type_ISO10163__SR__1_XSR__APDU, un.initialiseRequest), _ZInitialiseRequestISO10163_SR_1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[1] },
	{ IMP_OBJ, 0, 21, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[2] },
	{ OBJECT, OFFSET(struct type_ISO10163__SR__1_XSR__APDU, un.initialiseResponse), _ZInitialiseResponseISO10163_SR_1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[2] },
	{ IMP_OBJ, 0, 22, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[3] },
	{ OBJECT, OFFSET(struct type_ISO10163__SR__1_XSR__APDU, un.searchRequest), _ZSearchRequestISO10163_SR_1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[3] },
	{ IMP_OBJ, 0, 23, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[4] },
	{ OBJECT, OFFSET(struct type_ISO10163__SR__1_XSR__APDU, un.searchResponse), _ZSearchResponseISO10163_SR_1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[4] },
	{ IMP_OBJ, 0, 24, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[5] },
	{ OBJECT, OFFSET(struct type_ISO10163__SR__1_XSR__APDU, un.presentRequest), _ZPresentRequestISO10163_SR_1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[5] },
	{ IMP_OBJ, 0, 25, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[6] },
	{ OBJECT, OFFSET(struct type_ISO10163__SR__1_XSR__APDU, un.presentResponse), _ZPresentResponseISO10163_SR_1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[6] },
	{ IMP_OBJ, 0, 26, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[7] },
	{ OBJECT, OFFSET(struct type_ISO10163__SR__1_XSR__APDU, un.deleteResultSetRequest), _ZDeleteResultSetRequestISO10163_SR_1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[7] },
	{ IMP_OBJ, 0, 27, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[8] },
	{ OBJECT, OFFSET(struct type_ISO10163__SR__1_XSR__APDU, un.deleteResultSetResponse), _ZDeleteResultSetResponseISO10163_SR_1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[8] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[9] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[9] }
	};

static ptpe dt_ObjectDescriptorISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[10] },
	{ ETAG, 0, 7, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[10] },
	{ SOCTETSTRING, 0, 4, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[10] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[10] }
	};

static ptpe dt_THISEXTERNALISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[11] },
	{ SSEQ_START, 0, 8, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[11] },
	{ MEMALLOC, 0, sizeof (struct Extern ), 0, (char **)&_ZptrtabISO10163_SR_1[11] },
	{ OPTL, OFFSET(struct Extern , optionals), 0, 0, (char **)&_ZptrtabISO10163_SR_1[12] },
	{ OBJID, OFFSET(struct Extern , directReference), 6, FL_UNIVERSAL|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[12] },
	{ INTEGER, OFFSET(struct Extern , indirectReference), 2, FL_UNIVERSAL|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[13] },
	{ ETAG, 0, 7, FL_UNIVERSAL|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[10] },
	{ OCTET_PTR, OFFSET(struct Extern , dataValueDescriptor.value), 4, FL_UNIVERSAL|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[10] },
	{ OCTET_LEN, OFFSET(struct Extern , dataValueDescriptor.len), 4, FL_UNIVERSAL|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[10] },
	{ SCHOICE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[11] },
	{ SCTRL, OFFSET(struct Extern , offset), 0, 0, (char **)&_ZptrtabISO10163_SR_1[11] },
	{ ETAG, 0, 0, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[14] },
	{ ANY, OFFSET(struct Extern , singleASN1Type), -1, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[14] },
	{ OCTET_PTR, OFFSET(struct Extern , octetAligned.value), 1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[15] },
	{ OCTET_LEN, OFFSET(struct Extern , octetAligned.len), 1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[15] },
	{ BITSTR_PTR, OFFSET(struct Extern , arbitrary.value), 2, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[16] },
	{ BITSTR_LEN, OFFSET(struct Extern , arbitrary.len), 2, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[16] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[11] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[11] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[11] }
	};

static ptpe dt_InitialiseRequestISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[17] },
	{ SSEQ_START, 0, 16, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[17] },
	{ MEMALLOC, 0, sizeof (struct _InitialiseRequest ), 0, (char **)&_ZptrtabISO10163_SR_1[17] },
	{ OBJECT, OFFSET(struct _InitialiseRequest , referenceId), _ZReferenceIdISO10163_SR_1, FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[18] },
	{ BITSTRING, OFFSET(struct _InitialiseRequest , protocolVersion), 3, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[23] },
	{ BITSTRING, OFFSET(struct _InitialiseRequest , options), 4, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[24] },
	{ INTEGER, OFFSET(struct _InitialiseRequest , preferredMessageSize), 5, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[25] },
	{ INTEGER, OFFSET(struct _InitialiseRequest , maximumMessageSize), 6, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[26] },
	{ ETAG, 0, 7, FL_CONTEXT|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[19] },
	{ ANY, OFFSET(struct _InitialiseRequest , authentication), -1, FL_UNIVERSAL|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[19] },
	{ T_STRING, OFFSET(struct _InitialiseRequest , implementationId), 110, FL_CONTEXT|FL_OPTIONAL, NULLVP },
	{ T_STRING, OFFSET(struct _InitialiseRequest , implementationName), 111, FL_CONTEXT|FL_OPTIONAL, NULLVP },
	{ T_STRING, OFFSET(struct _InitialiseRequest , implementationVersion), 112, FL_CONTEXT|FL_OPTIONAL, NULLVP },
	{ OBJECT, OFFSET(struct _InitialiseRequest , userInformationField), _ZUserInformationFieldISO10163_SR_1, FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[20] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[17] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[17] }
	};

static ptpe dt_InitialiseResponseISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[21] },
	{ SSEQ_START, 0, 16, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[21] },
	{ MEMALLOC, 0, sizeof (struct _InitialiseResponse ), 0, (char **)&_ZptrtabISO10163_SR_1[21] },
	{ OBJECT, OFFSET(struct _InitialiseResponse , referenceId), _ZReferenceIdISO10163_SR_1, FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[18] },
	{ BITSTRING, OFFSET(struct _InitialiseResponse , protocolVersion), 3, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[23] },
	{ BITSTRING, OFFSET(struct _InitialiseResponse , options), 4, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[24] },
	{ INTEGER, OFFSET(struct _InitialiseResponse , preferredMessageSize), 5, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[25] },
	{ INTEGER, OFFSET(struct _InitialiseResponse , maximumMessageSize), 6, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[26] },
	{ BOOLEAN, OFFSET(struct _InitialiseResponse , initializationStatus), 12, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[22] },
	{ T_STRING, OFFSET(struct _InitialiseResponse , implementationId), 110, FL_CONTEXT|FL_OPTIONAL, NULLVP },
	{ T_STRING, OFFSET(struct _InitialiseResponse , implementationName), 111, FL_CONTEXT|FL_OPTIONAL, NULLVP },
	{ T_STRING, OFFSET(struct _InitialiseResponse , implementationVersion), 112, FL_CONTEXT|FL_OPTIONAL, NULLVP },
	{ OBJECT, OFFSET(struct _InitialiseResponse , userInformationField), _ZUserInformationFieldISO10163_SR_1, FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[20] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[21] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[21] }
	};

static ptpe dt_ProtocolVersionISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[23] },
	{ SBITSTRING, 0, 3, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[23] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[23] }
	};

static ptpe dt_OptionsISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[24] },
	{ SBITSTRING, 0, 4, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[24] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[24] }
	};

static ptpe dt_PreferredMessageSizeISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[25] },
	{ MEMALLOC, 0, sizeof (struct type_ISO10163__SR__1_PreferredMessageSize), 0, (char **)&_ZptrtabISO10163_SR_1[25] },
	{ INTEGER, OFFSET(struct type_ISO10163__SR__1_PreferredMessageSize, parm), 5, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[25] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[25] }
	};

static ptpe dt_MaximumMessageSizeISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[26] },
	{ MEMALLOC, 0, sizeof (struct type_ISO10163__SR__1_MaximumMessageSize), 0, (char **)&_ZptrtabISO10163_SR_1[26] },
	{ INTEGER, OFFSET(struct type_ISO10163__SR__1_MaximumMessageSize, parm), 6, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[26] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[26] }
	};

static ptpe dt_ImplementationIdISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[27] },
	{ SOCTETSTRING, 0, 110, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[27] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[27] }
	};

static ptpe dt_ImplementationNameISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[28] },
	{ SOCTETSTRING, 0, 111, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[28] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[28] }
	};

static ptpe dt_ImplementationVersionISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[29] },
	{ SOCTETSTRING, 0, 112, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[29] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[29] }
	};

static ptpe dt_UserInformationFieldISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[30] },
	{ ETAG, 0, 11, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[30] },
	{ SOBJECT, 0, _ZTHISEXTERNALISO10163_SR_1, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[30] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[30] }
	};

static ptpe dt_AuthenticationISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[31] },
	{ SSEQ_START, 0, 16, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[31] },
	{ MEMALLOC, 0, sizeof (struct _Authentication ), 0, (char **)&_ZptrtabISO10163_SR_1[31] },
	{ OCTET_PTR, OFFSET(struct _Authentication , user.value), 26, FL_UNIVERSAL, NULLVP },
	{ OCTET_LEN, OFFSET(struct _Authentication , user.len), 26, FL_UNIVERSAL, NULLVP },
	{ OCTET_PTR, OFFSET(struct _Authentication , password.value), 26, FL_UNIVERSAL, NULLVP },
	{ OCTET_LEN, OFFSET(struct _Authentication , password.len), 26, FL_UNIVERSAL, NULLVP },
	{ OCTET_PTR, OFFSET(struct _Authentication , account.value), 26, FL_UNIVERSAL, NULLVP },
	{ OCTET_LEN, OFFSET(struct _Authentication , password.len), 26, FL_UNIVERSAL, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[31] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[31] }
	};

static ptpe dt_SearchRequestISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[32] },
	{ SSEQ_START, 0, 16, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[32] },
	{ MEMALLOC, 0, sizeof (struct _SearchRequest ), 0, (char **)&_ZptrtabISO10163_SR_1[32] },
	{ OBJECT, OFFSET(struct _SearchRequest , referenceId), _ZReferenceIdISO10163_SR_1, FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[18] },
	{ INTEGER, OFFSET(struct _SearchRequest , smallSetUpperBound), 13, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[33] },
	{ INTEGER, OFFSET(struct _SearchRequest , largeSetLowerBound), 14, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[34] },
	{ INTEGER, OFFSET(struct _SearchRequest , mediumSetPresentNumber), 15, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[35] },
	{ BOOLEAN, OFFSET(struct _SearchRequest , replaceIndicator), 16, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[36] },
	{ T_STRING, OFFSET(struct _SearchRequest , proposedResultSetId), 17, FL_CONTEXT, NULLVP },
	{ SEQOF_START, OFFSET(struct _SearchRequest , databaseId), 18, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[37] },
	{ MEMALLOC, 0, sizeof (struct _SeqOf_DatabaseName ), 0, (char **)&_ZptrtabISO10163_SR_1[37] },
	{ T_STRING, OFFSET(struct _SeqOf_DatabaseName , name), 105, FL_CONTEXT, NULLVP },
	{ PE_END, OFFSET(struct _SeqOf_DatabaseName , next), 0, 0, (char **)&_ZptrtabISO10163_SR_1[37] },
	{ ETAG, 0, 100, FL_CONTEXT|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[38] },
	{ OBJECT, OFFSET(struct _SearchRequest , smallSetRecordComposition), _ZRecordCompositionISO10163_SR_1, FL_UNIVERSAL|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[38] },
	{ ETAG, 0, 101, FL_CONTEXT|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[39] },
	{ OBJECT, OFFSET(struct _SearchRequest , mediumSetRecordComposition), _ZRecordCompositionISO10163_SR_1, FL_UNIVERSAL|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[39] },
	{ OBJID, OFFSET(struct _SearchRequest , preferredRecordSyntax), 104, FL_CONTEXT|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[84] },
	{ ETAG, 0, 21, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[40] },
	{ OBJECT, OFFSET(struct _SearchRequest , query), _ZQueryISO10163_SR_1, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[40] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[32] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[32] }
	};

static ptpe dt_QueryISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[41] },
	{ SCHOICE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[41] },
	{ MEMALLOC, 0, sizeof (struct _Query ), 0, (char **)&_ZptrtabISO10163_SR_1[41] },
	{ SCTRL, OFFSET(struct _Query , offset), 0, 0, (char **)&_ZptrtabISO10163_SR_1[41] },
	{ ETAG, 0, 0, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[42] },
	{ ANY, OFFSET(struct _Query , privateQuery), -1, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[42] },
	{ IMP_OBJ, 0, 1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[43] },
	{ OBJECT, OFFSET(struct _Query , rpnQuery), _ZRPNQueryISO10163_SR_1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[43] },
	{ ETAG, 0, 2, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[44] },
	{ OCTET_PTR, OFFSET(struct _Query , iso8777Query.value), 4, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[44] },
	{ OCTET_LEN, OFFSET(struct _Query , iso8777Query.len), 4, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[44] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[41] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[41] }
	};

static ptpe dt_RPNQueryISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[45] },
	{ SSEQ_START, 0, 16, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[45] },
	{ MEMALLOC, 0, sizeof (struct _RPNQuery ), 0, (char **)&_ZptrtabISO10163_SR_1[45] },
	{ OBJID, OFFSET(struct _RPNQuery , attributeSetId), 6, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[46] },
	{ OBJECT, OFFSET(struct _RPNQuery , rpnStructure), _ZRPNStructureISO10163_SR_1, 0, (char **)&_ZptrtabISO10163_SR_1[45] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[45] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[45] }
	};

static ptpe dt_RPNStructureISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[47] },
	{ SCHOICE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[47] },
	{ MEMALLOC, 0, sizeof (struct _RPNStructure ), 0, (char **)&_ZptrtabISO10163_SR_1[47] },
	{ SCTRL, OFFSET(struct _RPNStructure , offset), 0, 0, (char **)&_ZptrtabISO10163_SR_1[47] },
	{ ETAG, 0, 0, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[47] },
	{ OBJECT, OFFSET(struct _RPNStructure , operand), _ZOperandISO10163_SR_1, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[47] },
	{ SSEQ_START, 0, 1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[47] },
	{ OBJECT, OFFSET(struct _RPNStructure , compound.rpnStructure1), _ZRPNStructureISO10163_SR_1, 0, (char **)&_ZptrtabISO10163_SR_1[47] },
	{ OBJECT, OFFSET(struct _RPNStructure , compound.rpnStructure2), _ZRPNStructureISO10163_SR_1, 0, (char **)&_ZptrtabISO10163_SR_1[47] },
	{ OBJECT, OFFSET(struct _RPNStructure , compound.operator), _ZOperatorISO10163_SR_1, 0, (char **)&_ZptrtabISO10163_SR_1[47] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[47] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[47] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[47] }
	};

static ptpe dt_OperandISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[48] },
	{ SCHOICE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[48] },
	{ MEMALLOC, 0, sizeof (struct _Operand ), 0, (char **)&_ZptrtabISO10163_SR_1[48] },
	{ SCTRL, OFFSET(struct _Operand , offset), 0, 0, (char **)&_ZptrtabISO10163_SR_1[48] },
	{ OBJECT, OFFSET(struct _Operand , attributesPlusTerm), _ZAttributesPlusTermISO10163_SR_1, 0, (char **)&_ZptrtabISO10163_SR_1[48] },
	{ T_STRING, OFFSET(struct _Operand , resultSetId), 31, FL_CONTEXT, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[48] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[48] }
	};

static ptpe dt_AttributesPlusTermISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[49] },
	{ SSEQ_START, 0, 102, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[49] },
	{ MEMALLOC, 0, sizeof (struct _AttributesPlusTerm ), 0, (char **)&_ZptrtabISO10163_SR_1[49] },
	{ OBJECT, OFFSET(struct _AttributesPlusTerm , attributeList), _ZAttributeListISO10163_SR_1, 0, (char **)&_ZptrtabISO10163_SR_1[49] },
	{ OBJECT, OFFSET(struct _AttributesPlusTerm , term), _ZTermISO10163_SR_1, 0, (char **)&_ZptrtabISO10163_SR_1[49] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[49] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[49] }
	};

static ptpe dt_AttributeListISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[50] },
	{ SSEQOF_START, 0, 44, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[50] },
	{ MEMALLOC, 0, sizeof (struct _AttributeList ), 0, (char **)&_ZptrtabISO10163_SR_1[50] },
	{ SOBJECT, 0, _ZAttributeElementISO10163_SR_1, 0, (char **)&_ZptrtabISO10163_SR_1[50] },
	{ PE_END, OFFSET(struct _AttributeList , next), 0, 0, (char **)&_ZptrtabISO10163_SR_1[50] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[50] }
	};

static ptpe dt_TermISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[51] },
	{ OCTET_PTR, OFFSET(struct octetString , value), 45, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[51] },
	{ OCTET_LEN, OFFSET(struct octetString , len), 45, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[51] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[51] }
	};

static ptpe dt_OperatorISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[52] },
	{ ETAG, 0, 46, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[52] },
	{ SCHOICE_START, 0, 0, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[52] },
	{ MEMALLOC, 0, sizeof (struct _Operator ), 0, (char **)&_ZptrtabISO10163_SR_1[52] },
	{ SCTRL, OFFSET(struct _Operator , offset), 0, 0, (char **)&_ZptrtabISO10163_SR_1[52] },
	{ T_NULL, 0, 0, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[53] },
	{ T_NULL, 0, 1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[54] },
	{ T_NULL, 0, 2, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[55] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[52] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[52] }
	};

static ptpe dt_AttributeElementISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[56] },
	{ SSEQ_START, 0, 16, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[56] },
	{ MEMALLOC, 0, sizeof (struct _AttributeElement ), 0, (char **)&_ZptrtabISO10163_SR_1[56] },
	{ INTEGER, OFFSET(struct _AttributeElement , attributeType), 120, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[57] },
	{ INTEGER, OFFSET(struct _AttributeElement , attributeValue), 121, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[58] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[56] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[56] }
	};

static ptpe dt_AttributeTypeISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[57] },
	{ MEMALLOC, 0, sizeof (struct type_ISO10163__SR__1_AttributeType), 0, (char **)&_ZptrtabISO10163_SR_1[57] },
	{ INTEGER, OFFSET(struct type_ISO10163__SR__1_AttributeType, parm), 120, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[57] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[57] }
	};

static ptpe dt_AttributeValueISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[58] },
	{ MEMALLOC, 0, sizeof (struct type_ISO10163__SR__1_AttributeValue), 0, (char **)&_ZptrtabISO10163_SR_1[58] },
	{ INTEGER, OFFSET(struct type_ISO10163__SR__1_AttributeValue, parm), 121, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[58] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[58] }
	};

static ptpe dt_SearchResponseISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[59] },
	{ SSEQ_START, 0, 16, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[59] },
	{ MEMALLOC, 0, sizeof (struct _SearchResponse ), 0, (char **)&_ZptrtabISO10163_SR_1[59] },
	{ OPTL, OFFSET(struct _SearchResponse , optionals), 0, 0, (char **)&_ZptrtabISO10163_SR_1[18] },
	{ OBJECT, OFFSET(struct _SearchResponse , referenceId), _ZReferenceIdISO10163_SR_1, FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[18] },
	{ INTEGER, OFFSET(struct _SearchResponse , numberOfRecordsFound), 23, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[60] },
	{ INTEGER, OFFSET(struct _SearchResponse , numberOfRecordsReturned), 24, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[81] },
	{ INTEGER, OFFSET(struct _SearchResponse , nextResultSetPosition), 25, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[82] },
	{ BOOLEAN, OFFSET(struct _SearchResponse , searchStatus), 22, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[61] },
	{ INTEGER, OFFSET(struct _SearchResponse , resultSetStatus), 26, FL_CONTEXT|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[62] },
	{ INTEGER, OFFSET(struct _SearchResponse , presentStatus), 27, FL_CONTEXT|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[83] },
	{ OBJECT, OFFSET(struct _SearchResponse , records), _ZRecordsISO10163_SR_1, FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[63] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[59] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[59] }
	};

static ptpe dt_PresentRequestISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[64] },
	{ SSEQ_START, 0, 16, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[64] },
	{ MEMALLOC, 0, sizeof (struct _PresentRequest ), 0, (char **)&_ZptrtabISO10163_SR_1[64] },
	{ OBJECT, OFFSET(struct _PresentRequest , referenceId), _ZReferenceIdISO10163_SR_1, FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[18] },
	{ T_STRING, OFFSET(struct _PresentRequest , resultSetId), 31, FL_CONTEXT, NULLVP },
	{ INTEGER, OFFSET(struct _PresentRequest , resultSetStartPoint), 30, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[65] },
	{ INTEGER, OFFSET(struct _PresentRequest , numberOfRecordsRequested), 29, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[66] },
	{ OBJECT, OFFSET(struct _PresentRequest , recordComposition), _ZRecordCompositionISO10163_SR_1, FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[64] },
	{ OBJID, OFFSET(struct _PresentRequest , preferredRecordSyntax), 104, FL_CONTEXT|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[84] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[64] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[64] }
	};

static ptpe dt_PresentResponseISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[67] },
	{ SSEQ_START, 0, 16, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[67] },
	{ MEMALLOC, 0, sizeof (struct type_ISO10163__SR__1_PresentResponse), 0, (char **)&_ZptrtabISO10163_SR_1[67] },
	{ OBJECT, OFFSET(struct type_ISO10163__SR__1_PresentResponse, referenceId), _ZReferenceIdISO10163_SR_1, FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[18] },
	{ INTEGER, OFFSET(struct type_ISO10163__SR__1_PresentResponse, numberOfRecordsReturned), 24, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[81] },
	{ INTEGER, OFFSET(struct type_ISO10163__SR__1_PresentResponse, nextResultSetPosition), 25, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[82] },
	{ INTEGER, OFFSET(struct type_ISO10163__SR__1_PresentResponse, presentStatus), 27, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[83] },
	{ OBJECT, OFFSET(struct type_ISO10163__SR__1_PresentResponse, records), _ZRecordsISO10163_SR_1, FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[63] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[67] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[67] }
	};

static ptpe dt_RecordsISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[68] },
	{ SCHOICE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[68] },
	{ MEMALLOC, 0, sizeof (struct _Records ), 0, (char **)&_ZptrtabISO10163_SR_1[68] },
	{ SCTRL, OFFSET(struct _Records , offset), 0, 0, (char **)&_ZptrtabISO10163_SR_1[68] },
	{ SEQOF_START, OFFSET(struct _Records , databaseOrSurDiagnostics), 28, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[69] },
	{ MEMALLOC, 0, sizeof (struct _NamePlusRecord ), 0, (char **)&_ZptrtabISO10163_SR_1[69] },
	{ SOBJECT, 0, _ZNamePlusRecordISO10163_SR_1, 0, (char **)&_ZptrtabISO10163_SR_1[68] },
	{ PE_END, OFFSET(struct _NamePlusRecord , next), 0, 0, (char **)&_ZptrtabISO10163_SR_1[69] },
	{ IMP_OBJ, 0, 130, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[70] },
	{ OBJECT, OFFSET(struct _Records , nonSurrogateDiagnostic), _ZDiagRecISO10163_SR_1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[70] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[68] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[68] }
	};

static ptpe dt_NamePlusRecordISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[71] },
	{ SSEQ_START, 0, 16, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[71] },
	{ MEMALLOC, 0, sizeof (struct _NamePlusRecord ), 0, (char **)&_ZptrtabISO10163_SR_1[71] },
	{ T_STRING, OFFSET(struct _NamePlusRecord , databaseName), 0, FL_CONTEXT|FL_OPTIONAL, NULLVP },
	{ ETAG, 0, 1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[71] },
	{ SCHOICE_START, 0, 0, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[71] },
	{ SCTRL, OFFSET(struct _NamePlusRecord , offset), 0, 0, (char **)&_ZptrtabISO10163_SR_1[71] },
	{ ETAG, 0, 1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[72] },
	{ OBJECT, OFFSET(struct _NamePlusRecord , databaseRecord), _ZDatabaseRecordISO10163_SR_1, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[72] },
	{ ETAG, 0, 2, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[73] },
	{ OBJECT, OFFSET(struct _NamePlusRecord , surrogateDiagnostic), _ZDiagRecISO10163_SR_1, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[73] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[71] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[71] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[71] }
	};

static ptpe dt_DatabaseRecordISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[74] },
	{ SOBJECT, 0, _ZTHISEXTERNALISO10163_SR_1, 0, (char **)&_ZptrtabISO10163_SR_1[74] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[74] }
	};

static ptpe dt_DiagRecISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[75] },
	{ SSEQ_START, 0, 16, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[75] },
	{ MEMALLOC, 0, sizeof (struct _DiagRec ), 0, (char **)&_ZptrtabISO10163_SR_1[75] },
	{ OBJID, OFFSET(struct _DiagRec , diagnosticSetId), 6, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[76] },
	{ INTEGER, OFFSET(struct _DiagRec , condition), 2, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[77] },
	{ T_STRING, OFFSET(struct _DiagRec , addinfo), 26, FL_UNIVERSAL, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[75] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[75] }
	};

static ptpe dt_RecordCompositionISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[78] },
	{ ETAG, 0, 19, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[78] },
	{ SCHOICE_START, 0, 0, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[78] },
	{ MEMALLOC, 0, sizeof (struct _RecordComposition ), 0, (char **)&_ZptrtabISO10163_SR_1[78] },
	{ SCTRL, OFFSET(struct _RecordComposition , offset), 0, 0, (char **)&_ZptrtabISO10163_SR_1[78] },
	{ T_STRING, OFFSET(struct _RecordComposition , generic), 0, FL_CONTEXT, NULLVP },
	{ SEQOF_START, OFFSET(struct _RecordComposition , databaseSpecific), 1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[79] },
	{ MEMALLOC, 0, sizeof (struct _RCDatabaseSpecific ), 0, (char **)&_ZptrtabISO10163_SR_1[79] },
	{ SSEQ_START, 0, 16, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[78] },
	{ T_STRING, OFFSET(struct _RCDatabaseSpecific , databaseName), 105, FL_CONTEXT, NULLVP },
	{ T_STRING, OFFSET(struct _RCDatabaseSpecific , recordCompositionId), 103, FL_CONTEXT, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[78] },
	{ PE_END, OFFSET(struct _RCDatabaseSpecific , next), 0, 0, (char **)&_ZptrtabISO10163_SR_1[79] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[78] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[78] }
	};

static ptpe dt_RecordCompositionIdISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[80] },
	{ SOCTETSTRING, 0, 103, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[80] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[80] }
	};

static ptpe dt_NumberOfRecordsReturnedISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[81] },
	{ MEMALLOC, 0, sizeof (struct type_ISO10163__SR__1_NumberOfRecordsReturned), 0, (char **)&_ZptrtabISO10163_SR_1[81] },
	{ INTEGER, OFFSET(struct type_ISO10163__SR__1_NumberOfRecordsReturned, parm), 24, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[81] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[81] }
	};

static ptpe dt_NextResultSetPositionISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[82] },
	{ MEMALLOC, 0, sizeof (struct type_ISO10163__SR__1_NextResultSetPosition), 0, (char **)&_ZptrtabISO10163_SR_1[82] },
	{ INTEGER, OFFSET(struct type_ISO10163__SR__1_NextResultSetPosition, parm), 25, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[82] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[82] }
	};

static ptpe dt_PresentStatusISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[83] },
	{ MEMALLOC, 0, sizeof (struct type_ISO10163__SR__1_PresentStatus), 0, (char **)&_ZptrtabISO10163_SR_1[83] },
	{ INTEGER, OFFSET(struct type_ISO10163__SR__1_PresentStatus, parm), 27, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[83] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[83] }
	};

static ptpe dt_PreferredRecordSyntaxISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[84] },
	{ SOBJID, 0, 104, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[84] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[84] }
	};

static ptpe dt_DeleteResultSetRequestISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[85] },
	{ SSEQ_START, 0, 16, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[85] },
	{ MEMALLOC, 0, sizeof (struct _DeleteResultSetRequest ), 0, (char **)&_ZptrtabISO10163_SR_1[85] },
	{ OBJECT, OFFSET(struct _DeleteResultSetRequest , referenceId), _ZReferenceIdISO10163_SR_1, FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[18] },
	{ INTEGER, OFFSET(struct _DeleteResultSetRequest , deleteSetFunction), 32, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[86] },
	{ SEQOF_START, OFFSET(struct _DeleteResultSetRequest , resultSetList), 16, FL_UNIVERSAL|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[87] },
	{ MEMALLOC, 0, sizeof (struct _ResultSetList ), 0, (char **)&_ZptrtabISO10163_SR_1[87] },
	{ T_STRING, OFFSET(struct _ResultSetList , resultSetId), 31, FL_CONTEXT, NULLVP },
	{ PE_END, OFFSET(struct _ResultSetList , next), 0, 0, (char **)&_ZptrtabISO10163_SR_1[87] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[85] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[85] }
	};

static ptpe dt_DeleteResultSetResponseISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[88] },
	{ SSEQ_START, 0, 16, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[88] },
	{ MEMALLOC, 0, sizeof (struct _DeleteResultSetResponse ), 0, (char **)&_ZptrtabISO10163_SR_1[88] },
	{ OPTL, OFFSET(struct _DeleteResultSetResponse , optionals), 0, 0, (char **)&_ZptrtabISO10163_SR_1[18] },
	{ OBJECT, OFFSET(struct _DeleteResultSetResponse , referenceId), _ZReferenceIdISO10163_SR_1, FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[18] },
	{ INTEGER, OFFSET(struct _DeleteResultSetResponse , deleteOperationStatus), 0, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[93] },
	{ IMP_OBJ, 0, 1, FL_CONTEXT|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[89] },
	{ OBJECT, OFFSET(struct _DeleteResultSetResponse , deleteListStatuses), _ZListStatusesISO10163_SR_1, FL_CONTEXT|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[89] },
	{ INTEGER, OFFSET(struct _DeleteResultSetResponse , numberNotDeleted), 34, FL_CONTEXT|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[90] },
	{ IMP_OBJ, 0, 35, FL_CONTEXT|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[91] },
	{ OBJECT, OFFSET(struct _DeleteResultSetResponse , bulkStatuses), _ZListStatusesISO10163_SR_1, FL_CONTEXT|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[91] },
	{ T_STRING, OFFSET(struct _DeleteResultSetResponse , deleteMessage), 36, FL_CONTEXT|FL_OPTIONAL, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[88] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[88] }
	};

static ptpe dt_ListStatusesISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[92] },
	{ SSEQOF_START, 0, 16, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[92] },
	{ MEMALLOC, 0, sizeof (struct _ListStatuses ), 0, (char **)&_ZptrtabISO10163_SR_1[92] },
	{ SSEQ_START, 0, 16, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[92] },
	{ T_STRING, OFFSET(struct _ListStatuses , resultSetId), 31, FL_CONTEXT, NULLVP },
	{ INTEGER, OFFSET(struct _ListStatuses , deleteSetStatus), 33, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[93] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[92] },
	{ PE_END, OFFSET(struct _ListStatuses , next), 0, 0, (char **)&_ZptrtabISO10163_SR_1[92] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[92] }
	};

static ptpe dt_DeleteSetStatusISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[93] },
	{ MEMALLOC, 0, sizeof (struct type_ISO10163__SR__1_DeleteSetStatus), 0, (char **)&_ZptrtabISO10163_SR_1[93] },
	{ INTEGER, OFFSET(struct type_ISO10163__SR__1_DeleteSetStatus, parm), 33, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[93] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[93] }
	};

static ptpe dt_ReferenceIdISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[94] },
	{ OCTET_PTR, OFFSET(struct octetString , value), 2, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[94] },
	{ OCTET_LEN, OFFSET(struct octetString , len), 2, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[94] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[94] }
	};

static ptpe dt_DatabaseNameISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[95] },
	{ SOCTETSTRING, 0, 105, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[95] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[95] }
	};

static ptpe dt_ResultSetIdISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[96] },
	{ SOCTETSTRING, 0, 31, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[96] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[96] }
	};

static ptpe pt_SR_APDUISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[0] },
	{ SCHOICE_START, -1, 0, 0, NULLVP },
	{ SCTRL, 0, 0, 0, NULLVP },
	{ ETAG, -1, 20, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[1] },
	{ ANY, -1, -1, FL_UNIVERSAL, NULLVP },
	{ ETAG, -1, 21, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[2] },
	{ ANY, -1, -1, FL_UNIVERSAL, NULLVP },
	{ ETAG, -1, 22, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[3] },
	{ ANY, -1, -1, FL_UNIVERSAL, NULLVP },
	{ ETAG, -1, 23, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[4] },
	{ ANY, -1, -1, FL_UNIVERSAL, NULLVP },
	{ ETAG, -1, 24, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[5] },
	{ ANY, -1, -1, FL_UNIVERSAL, NULLVP },
	{ ETAG, -1, 25, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[6] },
	{ ANY, -1, -1, FL_UNIVERSAL, NULLVP },
	{ ETAG, -1, 26, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[7] },
	{ ANY, -1, -1, FL_UNIVERSAL, NULLVP },
	{ ETAG, -1, 27, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[8] },
	{ ANY, -1, -1, FL_UNIVERSAL, NULLVP },
	{ PE_END, 0, 0, 0, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[0] }
	};

static ptpe pt_XSR_APDUISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[9] },
	{ SCHOICE_START, -1, 0, 0, NULLVP },
	{ SCTRL, 0, 0, 0, NULLVP },
	{ IMP_OBJ, -1, 20, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[1] },
	{ OBJECT, 0, _ZInitialiseRequestISO10163_SR_1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[1] },
	{ IMP_OBJ, -1, 21, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[2] },
	{ OBJECT, 0, _ZInitialiseResponseISO10163_SR_1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[2] },
	{ IMP_OBJ, -1, 22, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[3] },
	{ OBJECT, 0, _ZSearchRequestISO10163_SR_1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[3] },
	{ IMP_OBJ, -1, 23, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[4] },
	{ OBJECT, 0, _ZSearchResponseISO10163_SR_1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[4] },
	{ IMP_OBJ, -1, 24, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[5] },
	{ OBJECT, 0, _ZPresentRequestISO10163_SR_1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[5] },
	{ IMP_OBJ, -1, 25, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[6] },
	{ OBJECT, 0, _ZPresentResponseISO10163_SR_1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[6] },
	{ IMP_OBJ, -1, 26, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[7] },
	{ OBJECT, 0, _ZDeleteResultSetRequestISO10163_SR_1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[7] },
	{ IMP_OBJ, -1, 27, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[8] },
	{ OBJECT, 0, _ZDeleteResultSetResponseISO10163_SR_1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[8] },
	{ PE_END, 0, 0, 0, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[9] }
	};

static ptpe pt_ObjectDescriptorISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[10] },
	{ ETAG, -1, 7, FL_UNIVERSAL, NULLVP },
	{ SOCTETSTRING, -1, 4, FL_UNIVERSAL, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[10] }
	};

static ptpe pt_THISEXTERNALISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[11] },
	{ SSEQ_START, -1, 8, FL_UNIVERSAL, NULLVP },
	{ OBJID, -1, 6, FL_UNIVERSAL|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[12] },
	{ INTEGER, -1, 2, FL_UNIVERSAL|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[13] },
	{ ETAG, 0, 7, FL_UNIVERSAL|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[10] },
	{ OCTET_PTR, -1, 4, FL_UNIVERSAL|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[10] },
	{ OCTET_LEN, -1, 4, FL_UNIVERSAL|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[10] },
	{ SCHOICE_START, -1, 0, 0, NULLVP },
	{ SCTRL, 0, 0, 0, NULLVP },
	{ ETAG, -1, 0, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[14] },
	{ ANY, -1, -1, FL_UNIVERSAL, NULLVP },
	{ OCTET_PTR, -1, 1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[15] },
	{ OCTET_LEN, -1, 1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[15] },
	{ BITSTR_PTR, -1, 2, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[16] },
	{ BITSTR_LEN, -1, 2, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[16] },
	{ PE_END, 0, 0, 0, NULLVP },
	{ PE_END, 0, 0, 0, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[11] }
	};

static ptpe pt_InitialiseRequestISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[17] },
	{ SSEQ_START, -1, 16, FL_UNIVERSAL, NULLVP },
	{ OBJECT, 0, _ZReferenceIdISO10163_SR_1, FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[18] },
	{ BITSTRING, -1, 3, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[23] },
	{ BITSTRING, -1, 4, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[24] },
	{ INTEGER, -1, 5, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[25] },
	{ INTEGER, -1, 6, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[26] },
	{ ETAG, -1, 7, FL_CONTEXT|FL_OPTIONAL|FL_PRTAG, (char **)&_ZptrtabISO10163_SR_1[19] },
	{ ANY, -1, -1, FL_UNIVERSAL|FL_OPTIONAL, NULLVP },
	{ T_STRING, -1, 110, FL_CONTEXT|FL_OPTIONAL, NULLVP },
	{ T_STRING, -1, 111, FL_CONTEXT|FL_OPTIONAL, NULLVP },
	{ T_STRING, -1, 112, FL_CONTEXT|FL_OPTIONAL, NULLVP },
	{ OBJECT, 0, _ZUserInformationFieldISO10163_SR_1, FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[20] },
	{ PE_END, 0, 0, 0, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[17] }
	};

static ptpe pt_InitialiseResponseISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[21] },
	{ SSEQ_START, -1, 16, FL_UNIVERSAL, NULLVP },
	{ OBJECT, 0, _ZReferenceIdISO10163_SR_1, FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[18] },
	{ BITSTRING, -1, 3, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[23] },
	{ BITSTRING, -1, 4, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[24] },
	{ INTEGER, -1, 5, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[25] },
	{ INTEGER, -1, 6, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[26] },
	{ BOOLEAN, -1, 12, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[22] },
	{ T_STRING, -1, 110, FL_CONTEXT|FL_OPTIONAL, NULLVP },
	{ T_STRING, -1, 111, FL_CONTEXT|FL_OPTIONAL, NULLVP },
	{ T_STRING, -1, 112, FL_CONTEXT|FL_OPTIONAL, NULLVP },
	{ OBJECT, 0, _ZUserInformationFieldISO10163_SR_1, FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[20] },
	{ PE_END, 0, 0, 0, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[21] }
	};

static ptpe pt_ProtocolVersionISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[23] },
	{ SBITSTRING, -1, 3, FL_CONTEXT, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[23] }
	};

static ptpe pt_OptionsISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[24] },
	{ SBITSTRING, 97, 4, FL_CONTEXT, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[24] }
	};

static ptpe pt_PreferredMessageSizeISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[25] },
	{ INTEGER, -1, 5, FL_CONTEXT, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[25] }
	};

static ptpe pt_MaximumMessageSizeISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[26] },
	{ INTEGER, -1, 6, FL_CONTEXT, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[26] }
	};

static ptpe pt_ImplementationIdISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[27] },
	{ SOCTETSTRING, 0, 110, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[98] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[27] }
	};

static ptpe pt_ImplementationNameISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[28] },
	{ SOCTETSTRING, 0, 111, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[98] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[28] }
	};

static ptpe pt_ImplementationVersionISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[29] },
	{ SOCTETSTRING, 0, 112, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[98] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[29] }
	};

static ptpe pt_UserInformationFieldISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[30] },
	{ ETAG, -1, 11, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[11] },
	{ SOBJECT, 0, _ZTHISEXTERNALISO10163_SR_1, FL_UNIVERSAL, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[30] }
	};

static ptpe pt_AuthenticationISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[31] },
	{ SSEQ_START, -1, 16, FL_UNIVERSAL, NULLVP },
	{ OCTET_PTR, -1, 26, FL_UNIVERSAL, NULLVP },
	{ OCTET_LEN, -1, 26, FL_UNIVERSAL, NULLVP },
	{ OCTET_PTR, -1, 26, FL_UNIVERSAL, NULLVP },
	{ OCTET_LEN, -1, 26, FL_UNIVERSAL, NULLVP },
	{ OCTET_PTR, -1, 26, FL_UNIVERSAL, NULLVP },
	{ OCTET_LEN, -1, 26, FL_UNIVERSAL, NULLVP },
	{ PE_END, 0, 0, 0, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[31] }
	};

static ptpe pt_SearchRequestISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[32] },
	{ SSEQ_START, -1, 16, FL_UNIVERSAL, NULLVP },
	{ OBJECT, 0, _ZReferenceIdISO10163_SR_1, FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[18] },
	{ INTEGER, -1, 13, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[33] },
	{ INTEGER, -1, 14, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[34] },
	{ INTEGER, -1, 15, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[35] },
	{ BOOLEAN, -1, 16, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[36] },
	{ T_STRING, -1, 17, FL_CONTEXT, NULLVP },
	{ SEQOF_START, -1, 18, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[37] },
	{ T_STRING, -1, 105, FL_CONTEXT, NULLVP },
	{ PE_END, 0, 0, 0, NULLVP },
	{ ETAG, -1, 100, FL_CONTEXT|FL_OPTIONAL|FL_PRTAG, (char **)&_ZptrtabISO10163_SR_1[38] },
	{ OBJECT, 0, _ZRecordCompositionISO10163_SR_1, FL_UNIVERSAL|FL_OPTIONAL, NULLVP },
	{ ETAG, -1, 101, FL_CONTEXT|FL_OPTIONAL|FL_PRTAG, (char **)&_ZptrtabISO10163_SR_1[39] },
	{ OBJECT, 0, _ZRecordCompositionISO10163_SR_1, FL_UNIVERSAL|FL_OPTIONAL, NULLVP },
	{ OBJID, -1, 104, FL_CONTEXT|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[84] },
	{ ETAG, -1, 21, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[40] },
	{ OBJECT, 0, _ZQueryISO10163_SR_1, FL_UNIVERSAL, NULLVP },
	{ PE_END, 0, 0, 0, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[32] }
	};

static ptpe pt_QueryISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[41] },
	{ SCHOICE_START, -1, 0, 0, NULLVP },
	{ SCTRL, 0, 0, 0, NULLVP },
	{ ETAG, -1, 0, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[42] },
	{ ANY, -1, -1, FL_UNIVERSAL, NULLVP },
	{ IMP_OBJ, -1, 1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[43] },
	{ OBJECT, 0, _ZRPNQueryISO10163_SR_1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[43] },
	{ ETAG, -1, 2, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[44] },
	{ OCTET_PTR, -1, 4, FL_UNIVERSAL, NULLVP },
	{ OCTET_LEN, -1, 4, FL_UNIVERSAL, NULLVP },
	{ PE_END, 0, 0, 0, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[41] }
	};

static ptpe pt_RPNQueryISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[45] },
	{ SSEQ_START, -1, 16, FL_UNIVERSAL, NULLVP },
	{ OBJID, -1, 6, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[46] },
	{ OBJECT, 0, _ZRPNStructureISO10163_SR_1, 0, (char **)&_ZptrtabISO10163_SR_1[47] },
	{ PE_END, 0, 0, 0, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[45] }
	};

static ptpe pt_RPNStructureISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[47] },
	{ SCHOICE_START, -1, 0, 0, NULLVP },
	{ SCTRL, 0, 0, 0, NULLVP },
	{ ETAG, -1, 0, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[48] },
	{ OBJECT, 0, _ZOperandISO10163_SR_1, FL_UNIVERSAL, NULLVP },
	{ SSEQ_START, -1, 1, FL_CONTEXT, NULLVP },
	{ OBJECT, 0, _ZRPNStructureISO10163_SR_1, 0, (char **)&_ZptrtabISO10163_SR_1[47] },
	{ OBJECT, 0, _ZRPNStructureISO10163_SR_1, 0, (char **)&_ZptrtabISO10163_SR_1[47] },
	{ OBJECT, 0, _ZOperatorISO10163_SR_1, 0, (char **)&_ZptrtabISO10163_SR_1[52] },
	{ PE_END, 0, 0, 0, NULLVP },
	{ PE_END, 0, 0, 0, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[47] }
	};

static ptpe pt_OperandISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[48] },
	{ SCHOICE_START, -1, 0, 0, NULLVP },
	{ SCTRL, 0, 0, 0, NULLVP },
	{ OBJECT, 0, _ZAttributesPlusTermISO10163_SR_1, 0, (char **)&_ZptrtabISO10163_SR_1[49] },
	{ T_STRING, -1, 31, FL_CONTEXT, NULLVP },
	{ PE_END, 0, 0, 0, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[48] }
	};

static ptpe pt_AttributesPlusTermISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[49] },
	{ SSEQ_START, -1, 102, FL_CONTEXT, NULLVP },
	{ OBJECT, 0, _ZAttributeListISO10163_SR_1, 0, (char **)&_ZptrtabISO10163_SR_1[50] },
	{ OBJECT, 0, _ZTermISO10163_SR_1, 0, (char **)&_ZptrtabISO10163_SR_1[51] },
	{ PE_END, 0, 0, 0, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[49] }
	};

static ptpe pt_AttributeListISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[50] },
	{ SSEQOF_START, -1, 44, FL_CONTEXT, NULLVP },
	{ SOBJECT, 0, _ZAttributeElementISO10163_SR_1, 0, (char **)&_ZptrtabISO10163_SR_1[56] },
	{ PE_END, 0, 0, 0, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[50] }
	};

static ptpe pt_TermISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[51] },
	{ OCTET_PTR, -1, 45, FL_CONTEXT, NULLVP },
	{ OCTET_LEN, -1, 45, FL_CONTEXT, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[51] }
	};

static ptpe pt_OperatorISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[52] },
	{ ETAG, -1, 46, FL_CONTEXT, NULLVP },
	{ SCHOICE_START, -1, 0, FL_UNIVERSAL, NULLVP },
	{ SCTRL, 0, 0, 0, NULLVP },
	{ T_NULL, -1, 0, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[53] },
	{ T_NULL, -1, 1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[54] },
	{ T_NULL, -1, 2, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[55] },
	{ PE_END, 0, 0, 0, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[52] }
	};

static ptpe pt_AttributeElementISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[56] },
	{ SSEQ_START, -1, 16, FL_UNIVERSAL, NULLVP },
	{ INTEGER, -1, 120, FL_CONTEXT, NULLVP },
	{ INTEGER, -1, 121, FL_CONTEXT, NULLVP },
	{ PE_END, 0, 0, 0, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[56] }
	};

static ptpe pt_AttributeTypeISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[57] },
	{ INTEGER, -1, 120, FL_CONTEXT, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[57] }
	};

static ptpe pt_AttributeValueISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[58] },
	{ INTEGER, -1, 121, FL_CONTEXT, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[58] }
	};

static ptpe pt_SearchResponseISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[59] },
	{ SSEQ_START, -1, 16, FL_UNIVERSAL, NULLVP },
	{ OBJECT, 0, _ZReferenceIdISO10163_SR_1, FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[18] },
	{ INTEGER, -1, 23, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[60] },
	{ INTEGER, -1, 24, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[81] },
	{ INTEGER, -1, 25, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[82] },
	{ BOOLEAN, -1, 22, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[61] },
	{ INTEGER, -1, 26, FL_CONTEXT|FL_OPTIONAL|FL_PRTAG, (char **)&_ZptrtabISO10163_SR_1[62] },
	{ INTEGER, -1, 27, FL_CONTEXT|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[83] },
	{ OBJECT, 0, _ZRecordsISO10163_SR_1, FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[63] },
	{ PE_END, 0, 0, 0, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[59] }
	};

static ptpe pt_PresentRequestISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[64] },
	{ SSEQ_START, -1, 16, FL_UNIVERSAL, NULLVP },
	{ OBJECT, 0, _ZReferenceIdISO10163_SR_1, FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[18] },
	{ T_STRING, -1, 31, FL_CONTEXT, NULLVP },
	{ INTEGER, -1, 30, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[65] },
	{ INTEGER, -1, 29, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[66] },
	{ OBJECT, 0, _ZRecordCompositionISO10163_SR_1, FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[78] },
	{ OBJID, -1, 104, FL_CONTEXT|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[84] },
	{ PE_END, 0, 0, 0, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[64] }
	};

static ptpe pt_PresentResponseISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[67] },
	{ SSEQ_START, -1, 16, FL_UNIVERSAL, NULLVP },
	{ OBJECT, 0, _ZReferenceIdISO10163_SR_1, FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[18] },
	{ INTEGER, -1, 24, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[81] },
	{ INTEGER, -1, 25, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[82] },
	{ INTEGER, -1, 27, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[83] },
	{ OBJECT, 0, _ZRecordsISO10163_SR_1, FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[63] },
	{ PE_END, 0, 0, 0, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[67] }
	};

static ptpe pt_RecordsISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[68] },
	{ SCHOICE_START, -1, 0, 0, NULLVP },
	{ SCTRL, 0, 0, 0, NULLVP },
	{ SEQOF_START, -1, 28, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[69] },
	{ SOBJECT, 0, _ZNamePlusRecordISO10163_SR_1, 0, (char **)&_ZptrtabISO10163_SR_1[71] },
	{ PE_END, 0, 0, 0, NULLVP },
	{ IMP_OBJ, -1, 130, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[70] },
	{ OBJECT, 0, _ZDiagRecISO10163_SR_1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[70] },
	{ PE_END, 0, 0, 0, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[68] }
	};

static ptpe pt_NamePlusRecordISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[71] },
	{ SSEQ_START, -1, 16, FL_UNIVERSAL, NULLVP },
	{ T_STRING, -1, 0, FL_CONTEXT|FL_OPTIONAL, NULLVP },
	{ ETAG, -1, 1, FL_CONTEXT, NULLVP },
	{ SCHOICE_START, -1, 0, FL_UNIVERSAL, NULLVP },
	{ SCTRL, 0, 0, 0, NULLVP },
	{ ETAG, -1, 1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[72] },
	{ OBJECT, 0, _ZDatabaseRecordISO10163_SR_1, FL_UNIVERSAL, NULLVP },
	{ ETAG, -1, 2, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[73] },
	{ OBJECT, 0, _ZDiagRecISO10163_SR_1, FL_UNIVERSAL, NULLVP },
	{ PE_END, 0, 0, 0, NULLVP },
	{ PE_END, 0, 0, 0, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[71] }
	};

static ptpe pt_DatabaseRecordISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[74] },
	{ SOBJECT, 0, _ZTHISEXTERNALISO10163_SR_1, 0, (char **)&_ZptrtabISO10163_SR_1[11] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[74] }
	};

static ptpe pt_DiagRecISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[75] },
	{ SSEQ_START, -1, 16, FL_UNIVERSAL, NULLVP },
	{ OBJID, -1, 6, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[76] },
	{ INTEGER, -1, 2, FL_UNIVERSAL, (char **)&_ZptrtabISO10163_SR_1[77] },
	{ T_STRING, -1, 26, FL_UNIVERSAL, NULLVP },
	{ PE_END, 0, 0, 0, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[75] }
	};

static ptpe pt_RecordCompositionISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[78] },
	{ ETAG, -1, 19, FL_CONTEXT, NULLVP },
	{ SCHOICE_START, -1, 0, FL_UNIVERSAL, NULLVP },
	{ SCTRL, 0, 0, 0, NULLVP },
	{ T_STRING, -1, 0, FL_CONTEXT, NULLVP },
	{ SEQOF_START, -1, 1, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[79] },
	{ SSEQ_START, -1, 16, FL_UNIVERSAL, NULLVP },
	{ T_STRING, -1, 105, FL_CONTEXT, NULLVP },
	{ T_STRING, -1, 103, FL_CONTEXT, NULLVP },
	{ PE_END, 0, 0, 0, NULLVP },
	{ PE_END, 0, 0, 0, NULLVP },
	{ PE_END, 0, 0, 0, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[78] }
	};

static ptpe pt_RecordCompositionIdISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[80] },
	{ SOCTETSTRING, 0, 103, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[98] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[80] }
	};

static ptpe pt_NumberOfRecordsReturnedISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[81] },
	{ INTEGER, -1, 24, FL_CONTEXT, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[81] }
	};

static ptpe pt_NextResultSetPositionISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[82] },
	{ INTEGER, -1, 25, FL_CONTEXT, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[82] }
	};

static ptpe pt_PresentStatusISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[83] },
	{ INTEGER, -1, 27, FL_CONTEXT, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[83] }
	};

static ptpe pt_PreferredRecordSyntaxISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[84] },
	{ SOBJID, -1, 104, FL_CONTEXT, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[84] }
	};

static ptpe pt_DeleteResultSetRequestISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[85] },
	{ SSEQ_START, -1, 16, FL_UNIVERSAL, NULLVP },
	{ OBJECT, 0, _ZReferenceIdISO10163_SR_1, FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[18] },
	{ INTEGER, -1, 32, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[86] },
	{ SEQOF_START, -1, 16, FL_UNIVERSAL|FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[87] },
	{ T_STRING, -1, 31, FL_CONTEXT, NULLVP },
	{ PE_END, 0, 0, 0, NULLVP },
	{ PE_END, 0, 0, 0, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[85] }
	};

static ptpe pt_DeleteResultSetResponseISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[88] },
	{ SSEQ_START, -1, 16, FL_UNIVERSAL, NULLVP },
	{ OBJECT, 0, _ZReferenceIdISO10163_SR_1, FL_OPTIONAL, (char **)&_ZptrtabISO10163_SR_1[18] },
	{ INTEGER, -1, 0, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[93] },
	{ IMP_OBJ, -1, 1, FL_CONTEXT|FL_OPTIONAL|FL_PRTAG, (char **)&_ZptrtabISO10163_SR_1[89] },
	{ OBJECT, 0, _ZListStatusesISO10163_SR_1, FL_CONTEXT|FL_OPTIONAL|FL_PRTAG, (char **)&_ZptrtabISO10163_SR_1[89] },
	{ INTEGER, -1, 34, FL_CONTEXT|FL_OPTIONAL|FL_PRTAG, (char **)&_ZptrtabISO10163_SR_1[90] },
	{ IMP_OBJ, -1, 35, FL_CONTEXT|FL_OPTIONAL|FL_PRTAG, (char **)&_ZptrtabISO10163_SR_1[91] },
	{ OBJECT, 0, _ZListStatusesISO10163_SR_1, FL_CONTEXT|FL_OPTIONAL|FL_PRTAG, (char **)&_ZptrtabISO10163_SR_1[91] },
	{ T_STRING, -1, 36, FL_CONTEXT|FL_OPTIONAL|FL_PRTAG, NULLVP },
	{ PE_END, 0, 0, 0, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[88] }
	};

static ptpe pt_ListStatusesISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[92] },
	{ SSEQOF_START, -1, 16, FL_UNIVERSAL, NULLVP },
	{ SSEQ_START, -1, 16, FL_UNIVERSAL, NULLVP },
	{ T_STRING, -1, 31, FL_CONTEXT, NULLVP },
	{ INTEGER, -1, 33, FL_CONTEXT, NULLVP },
	{ PE_END, 0, 0, 0, NULLVP },
	{ PE_END, 0, 0, 0, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[92] }
	};

static ptpe pt_DeleteSetStatusISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[93] },
	{ INTEGER, -1, 33, FL_CONTEXT, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[93] }
	};

static ptpe pt_ReferenceIdISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[94] },
	{ OCTET_PTR, -1, 2, FL_CONTEXT, NULLVP },
	{ OCTET_LEN, -1, 2, FL_CONTEXT, NULLVP },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[94] }
	};

static ptpe pt_DatabaseNameISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[95] },
	{ SOCTETSTRING, 0, 105, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[98] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[95] }
	};

static ptpe pt_ResultSetIdISO10163_SR_1[] = {
	{ PE_START, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[96] },
	{ SOCTETSTRING, 0, 31, FL_CONTEXT, (char **)&_ZptrtabISO10163_SR_1[98] },
	{ PE_END, 0, 0, 0, (char **)&_ZptrtabISO10163_SR_1[96] }
	};

static ptpe *etabl[] = {
	et_SR_APDUISO10163_SR_1,
	et_XSR_APDUISO10163_SR_1,
	et_ObjectDescriptorISO10163_SR_1,
	et_THISEXTERNALISO10163_SR_1,
	et_InitialiseRequestISO10163_SR_1,
	et_InitialiseResponseISO10163_SR_1,
	et_ProtocolVersionISO10163_SR_1,
	et_OptionsISO10163_SR_1,
	et_PreferredMessageSizeISO10163_SR_1,
	et_MaximumMessageSizeISO10163_SR_1,
	et_ImplementationIdISO10163_SR_1,
	et_ImplementationNameISO10163_SR_1,
	et_ImplementationVersionISO10163_SR_1,
	et_UserInformationFieldISO10163_SR_1,
	et_AuthenticationISO10163_SR_1,
	et_SearchRequestISO10163_SR_1,
	et_QueryISO10163_SR_1,
	et_RPNQueryISO10163_SR_1,
	et_RPNStructureISO10163_SR_1,
	et_OperandISO10163_SR_1,
	et_AttributesPlusTermISO10163_SR_1,
	et_AttributeListISO10163_SR_1,
	et_TermISO10163_SR_1,
	et_OperatorISO10163_SR_1,
	et_AttributeElementISO10163_SR_1,
	et_AttributeTypeISO10163_SR_1,
	et_AttributeValueISO10163_SR_1,
	et_SearchResponseISO10163_SR_1,
	et_PresentRequestISO10163_SR_1,
	et_PresentResponseISO10163_SR_1,
	et_RecordsISO10163_SR_1,
	et_NamePlusRecordISO10163_SR_1,
	et_DatabaseRecordISO10163_SR_1,
	et_DiagRecISO10163_SR_1,
	et_RecordCompositionISO10163_SR_1,
	et_RecordCompositionIdISO10163_SR_1,
	et_NumberOfRecordsReturnedISO10163_SR_1,
	et_NextResultSetPositionISO10163_SR_1,
	et_PresentStatusISO10163_SR_1,
	et_PreferredRecordSyntaxISO10163_SR_1,
	et_DeleteResultSetRequestISO10163_SR_1,
	et_DeleteResultSetResponseISO10163_SR_1,
	et_ListStatusesISO10163_SR_1,
	et_DeleteSetStatusISO10163_SR_1,
	et_ReferenceIdISO10163_SR_1,
	et_DatabaseNameISO10163_SR_1,
	et_ResultSetIdISO10163_SR_1,
	};

static ptpe *dtabl[] = {
	dt_SR_APDUISO10163_SR_1,
	dt_XSR_APDUISO10163_SR_1,
	dt_ObjectDescriptorISO10163_SR_1,
	dt_THISEXTERNALISO10163_SR_1,
	dt_InitialiseRequestISO10163_SR_1,
	dt_InitialiseResponseISO10163_SR_1,
	dt_ProtocolVersionISO10163_SR_1,
	dt_OptionsISO10163_SR_1,
	dt_PreferredMessageSizeISO10163_SR_1,
	dt_MaximumMessageSizeISO10163_SR_1,
	dt_ImplementationIdISO10163_SR_1,
	dt_ImplementationNameISO10163_SR_1,
	dt_ImplementationVersionISO10163_SR_1,
	dt_UserInformationFieldISO10163_SR_1,
	dt_AuthenticationISO10163_SR_1,
	dt_SearchRequestISO10163_SR_1,
	dt_QueryISO10163_SR_1,
	dt_RPNQueryISO10163_SR_1,
	dt_RPNStructureISO10163_SR_1,
	dt_OperandISO10163_SR_1,
	dt_AttributesPlusTermISO10163_SR_1,
	dt_AttributeListISO10163_SR_1,
	dt_TermISO10163_SR_1,
	dt_OperatorISO10163_SR_1,
	dt_AttributeElementISO10163_SR_1,
	dt_AttributeTypeISO10163_SR_1,
	dt_AttributeValueISO10163_SR_1,
	dt_SearchResponseISO10163_SR_1,
	dt_PresentRequestISO10163_SR_1,
	dt_PresentResponseISO10163_SR_1,
	dt_RecordsISO10163_SR_1,
	dt_NamePlusRecordISO10163_SR_1,
	dt_DatabaseRecordISO10163_SR_1,
	dt_DiagRecISO10163_SR_1,
	dt_RecordCompositionISO10163_SR_1,
	dt_RecordCompositionIdISO10163_SR_1,
	dt_NumberOfRecordsReturnedISO10163_SR_1,
	dt_NextResultSetPositionISO10163_SR_1,
	dt_PresentStatusISO10163_SR_1,
	dt_PreferredRecordSyntaxISO10163_SR_1,
	dt_DeleteResultSetRequestISO10163_SR_1,
	dt_DeleteResultSetResponseISO10163_SR_1,
	dt_ListStatusesISO10163_SR_1,
	dt_DeleteSetStatusISO10163_SR_1,
	dt_ReferenceIdISO10163_SR_1,
	dt_DatabaseNameISO10163_SR_1,
	dt_ResultSetIdISO10163_SR_1,
	};

static ptpe *ptabl[] = {
	pt_SR_APDUISO10163_SR_1,
	pt_XSR_APDUISO10163_SR_1,
	pt_ObjectDescriptorISO10163_SR_1,
	pt_THISEXTERNALISO10163_SR_1,
	pt_InitialiseRequestISO10163_SR_1,
	pt_InitialiseResponseISO10163_SR_1,
	pt_ProtocolVersionISO10163_SR_1,
	pt_OptionsISO10163_SR_1,
	pt_PreferredMessageSizeISO10163_SR_1,
	pt_MaximumMessageSizeISO10163_SR_1,
	pt_ImplementationIdISO10163_SR_1,
	pt_ImplementationNameISO10163_SR_1,
	pt_ImplementationVersionISO10163_SR_1,
	pt_UserInformationFieldISO10163_SR_1,
	pt_AuthenticationISO10163_SR_1,
	pt_SearchRequestISO10163_SR_1,
	pt_QueryISO10163_SR_1,
	pt_RPNQueryISO10163_SR_1,
	pt_RPNStructureISO10163_SR_1,
	pt_OperandISO10163_SR_1,
	pt_AttributesPlusTermISO10163_SR_1,
	pt_AttributeListISO10163_SR_1,
	pt_TermISO10163_SR_1,
	pt_OperatorISO10163_SR_1,
	pt_AttributeElementISO10163_SR_1,
	pt_AttributeTypeISO10163_SR_1,
	pt_AttributeValueISO10163_SR_1,
	pt_SearchResponseISO10163_SR_1,
	pt_PresentRequestISO10163_SR_1,
	pt_PresentResponseISO10163_SR_1,
	pt_RecordsISO10163_SR_1,
	pt_NamePlusRecordISO10163_SR_1,
	pt_DatabaseRecordISO10163_SR_1,
	pt_DiagRecISO10163_SR_1,
	pt_RecordCompositionISO10163_SR_1,
	pt_RecordCompositionIdISO10163_SR_1,
	pt_NumberOfRecordsReturnedISO10163_SR_1,
	pt_NextResultSetPositionISO10163_SR_1,
	pt_PresentStatusISO10163_SR_1,
	pt_PreferredRecordSyntaxISO10163_SR_1,
	pt_DeleteResultSetRequestISO10163_SR_1,
	pt_DeleteResultSetResponseISO10163_SR_1,
	pt_ListStatusesISO10163_SR_1,
	pt_DeleteSetStatusISO10163_SR_1,
	pt_ReferenceIdISO10163_SR_1,
	pt_DatabaseNameISO10163_SR_1,
	pt_ResultSetIdISO10163_SR_1,
	};


/* Pointer table 99 entries */
caddr_t _ZptrtabISO10163_SR_1[] = {
    (caddr_t ) "SR-APDU",
    (caddr_t ) "initialiseRequest",
    (caddr_t ) "initialiseResponse",
    (caddr_t ) "searchRequest",
    (caddr_t ) "searchResponse",
    (caddr_t ) "presentRequest",
    (caddr_t ) "presentResponse",
    (caddr_t ) "deleteResultSetRequest",
    (caddr_t ) "deleteResultSetResponse",
    (caddr_t ) "XSR-APDU",
    (caddr_t ) "ObjectDescriptor",
    (caddr_t ) "THISEXTERNAL",
    (caddr_t ) "direct-reference",
    (caddr_t ) "indirect-reference",
    (caddr_t ) "single-ASN1-type",
    (caddr_t ) "octet-aligned",
    (caddr_t ) "arbitrary",
    (caddr_t ) "InitialiseRequest",
    (caddr_t ) "referenceId",
    (caddr_t ) "authentication",
    (caddr_t ) "userInformationField",
    (caddr_t ) "InitialiseResponse",
    (caddr_t ) "initializationStatus",
    (caddr_t ) "ProtocolVersion",
    (caddr_t ) "Options",
    (caddr_t ) "PreferredMessageSize",
    (caddr_t ) "MaximumMessageSize",
    (caddr_t ) "ImplementationId",
    (caddr_t ) "ImplementationName",
    (caddr_t ) "ImplementationVersion",
    (caddr_t ) "UserInformationField",
    (caddr_t ) "Authentication",
    (caddr_t ) "SearchRequest",
    (caddr_t ) "smallSetUpperBound",
    (caddr_t ) "largeSetLowerBound",
    (caddr_t ) "mediumSetPresentNumber",
    (caddr_t ) "replaceIndicator",
    (caddr_t ) "databaseId",
    (caddr_t ) "smallSetRecordComposition",
    (caddr_t ) "mediumSetRecordComposition",
    (caddr_t ) "query",
    (caddr_t ) "Query",
    (caddr_t ) "privateQuery",
    (caddr_t ) "rpnQuery",
    (caddr_t ) "iso8777query",
    (caddr_t ) "RPNQuery",
    (caddr_t ) "attributeSetId",
    (caddr_t ) "RPNStructure",
    (caddr_t ) "Operand",
    (caddr_t ) "AttributesPlusTerm",
    (caddr_t ) "AttributeList",
    (caddr_t ) "Term",
    (caddr_t ) "Operator",
    (caddr_t ) "and",
    (caddr_t ) "or",
    (caddr_t ) "and-not",
    (caddr_t ) "AttributeElement",
    (caddr_t ) "AttributeType",
    (caddr_t ) "AttributeValue",
    (caddr_t ) "SearchResponse",
    (caddr_t ) "numberOfRecordsFound",
    (caddr_t ) "searchStatus",
    (caddr_t ) "resultSetStatus",
    (caddr_t ) "records",
    (caddr_t ) "PresentRequest",
    (caddr_t ) "resultSetStartPoint",
    (caddr_t ) "numberOfRecordsRequested",
    (caddr_t ) "PresentResponse",
    (caddr_t ) "Records",
    (caddr_t ) "dataBaseOrSurDiagnostics",
    (caddr_t ) "nonSurrogateDiagnostic",
    (caddr_t ) "NamePlusRecord",
    (caddr_t ) "databaseRecord",
    (caddr_t ) "surrogateDiagnostic",
    (caddr_t ) "DatabaseRecord",
    (caddr_t ) "DiagRec",
    (caddr_t ) "diagnosticSetId",
    (caddr_t ) "condition",
    (caddr_t ) "RecordComposition",
    (caddr_t ) "databaseSpecific",
    (caddr_t ) "RecordCompositionId",
    (caddr_t ) "NumberOfRecordsReturned",
    (caddr_t ) "NextResultSetPosition",
    (caddr_t ) "PresentStatus",
    (caddr_t ) "PreferredRecordSyntax",
    (caddr_t ) "DeleteResultSetRequest",
    (caddr_t ) "deleteSetFunction",
    (caddr_t ) "resultSetList",
    (caddr_t ) "DeleteResultSetResponse",
    (caddr_t ) "deleteListStatuses",
    (caddr_t ) "numberNotDeleted",
    (caddr_t ) "bulkStatuses",
    (caddr_t ) "ListStatuses",
    (caddr_t ) "DeleteSetStatus",
    (caddr_t ) "ReferenceId",
    (caddr_t ) "DatabaseName",
    (caddr_t ) "ResultSetId",
    (caddr_t ) bits_ISO10163__SR__1_Options,
    (caddr_t ) "VisibleString",
};

modtyp _ZISO10163_SR_1_mod = {
	"ISO10163-SR-1",
	47,
	etabl,
	dtabl,
	ptabl,
	0,
	0,
	0,
	_ZptrtabISO10163_SR_1,
	};


#if	defined(lint) || defined(PEPSY_LINKABLE_FUNCS)

#undef encode_ISO10163__SR__1_SR__APDU
int	encode_ISO10163__SR__1_SR__APDU(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct _SR_APDU  *parm;
{
  return (enc_f(_ZSR_APDUISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_SR__APDU
int	decode_ISO10163__SR__1_SR__APDU(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _SR_APDU  **parm;
{
  return (dec_f(_ZSR_APDUISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_SR__APDU
/* ARGSUSED */
int	print_ISO10163__SR__1_SR__APDU(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _SR_APDU  *parm;
{
  return (prnt_f(_ZSR_APDUISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef free_ISO10163__SR__1_SR__APDU
void free_ISO10163__SR__1_SR__APDU(val)
struct _SR_APDU  *val;
{
(void) fre_obj((char *) val, _ZISO10163_SR_1_mod.md_dtab[_ZSR_APDUISO10163_SR_1], &_ZISO10163_SR_1_mod, 1);
}

#undef encode_ISO10163__SR__1_XSR__APDU
int	encode_ISO10163__SR__1_XSR__APDU(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct type_ISO10163__SR__1_XSR__APDU *parm;
{
  return (enc_f(_ZXSR_APDUISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_XSR__APDU
int	decode_ISO10163__SR__1_XSR__APDU(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_XSR__APDU **parm;
{
  return (dec_f(_ZXSR_APDUISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_XSR__APDU
/* ARGSUSED */
int	print_ISO10163__SR__1_XSR__APDU(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_XSR__APDU *parm;
{
  return (prnt_f(_ZXSR_APDUISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef free_ISO10163__SR__1_XSR__APDU
void free_ISO10163__SR__1_XSR__APDU(val)
struct type_ISO10163__SR__1_XSR__APDU *val;
{
(void) fre_obj((char *) val, _ZISO10163_SR_1_mod.md_dtab[_ZXSR_APDUISO10163_SR_1], &_ZISO10163_SR_1_mod, 1);
}

#undef encode_ISO10163__SR__1_ObjectDescriptor
int	encode_ISO10163__SR__1_ObjectDescriptor(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct type_ISO10163__SR__1_ObjectDescriptor *parm;
{
  return (enc_f(_ZObjectDescriptorISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_ObjectDescriptor
int	decode_ISO10163__SR__1_ObjectDescriptor(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_ObjectDescriptor **parm;
{
  return (dec_f(_ZObjectDescriptorISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_ObjectDescriptor
/* ARGSUSED */
int	print_ISO10163__SR__1_ObjectDescriptor(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_ObjectDescriptor *parm;
{
  return (prnt_f(_ZObjectDescriptorISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef encode_ISO10163__SR__1_THISEXTERNAL
int	encode_ISO10163__SR__1_THISEXTERNAL(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct Extern  *parm;
{
  return (enc_f(_ZTHISEXTERNALISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_THISEXTERNAL
int	decode_ISO10163__SR__1_THISEXTERNAL(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct Extern  **parm;
{
  return (dec_f(_ZTHISEXTERNALISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_THISEXTERNAL
/* ARGSUSED */
int	print_ISO10163__SR__1_THISEXTERNAL(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct Extern  *parm;
{
  return (prnt_f(_ZTHISEXTERNALISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef free_ISO10163__SR__1_THISEXTERNAL
void free_ISO10163__SR__1_THISEXTERNAL(val)
struct Extern  *val;
{
(void) fre_obj((char *) val, _ZISO10163_SR_1_mod.md_dtab[_ZTHISEXTERNALISO10163_SR_1], &_ZISO10163_SR_1_mod, 1);
}

#undef encode_ISO10163__SR__1_InitialiseRequest
int	encode_ISO10163__SR__1_InitialiseRequest(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct _InitialiseRequest  *parm;
{
  return (enc_f(_ZInitialiseRequestISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_InitialiseRequest
int	decode_ISO10163__SR__1_InitialiseRequest(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _InitialiseRequest  **parm;
{
  return (dec_f(_ZInitialiseRequestISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_InitialiseRequest
/* ARGSUSED */
int	print_ISO10163__SR__1_InitialiseRequest(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _InitialiseRequest  *parm;
{
  return (prnt_f(_ZInitialiseRequestISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef free_ISO10163__SR__1_InitialiseRequest
void free_ISO10163__SR__1_InitialiseRequest(val)
struct _InitialiseRequest  *val;
{
(void) fre_obj((char *) val, _ZISO10163_SR_1_mod.md_dtab[_ZInitialiseRequestISO10163_SR_1], &_ZISO10163_SR_1_mod, 1);
}

#undef encode_ISO10163__SR__1_InitialiseResponse
int	encode_ISO10163__SR__1_InitialiseResponse(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct _InitialiseResponse  *parm;
{
  return (enc_f(_ZInitialiseResponseISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_InitialiseResponse
int	decode_ISO10163__SR__1_InitialiseResponse(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _InitialiseResponse  **parm;
{
  return (dec_f(_ZInitialiseResponseISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_InitialiseResponse
/* ARGSUSED */
int	print_ISO10163__SR__1_InitialiseResponse(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _InitialiseResponse  *parm;
{
  return (prnt_f(_ZInitialiseResponseISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef free_ISO10163__SR__1_InitialiseResponse
void free_ISO10163__SR__1_InitialiseResponse(val)
struct _InitialiseResponse  *val;
{
(void) fre_obj((char *) val, _ZISO10163_SR_1_mod.md_dtab[_ZInitialiseResponseISO10163_SR_1], &_ZISO10163_SR_1_mod, 1);
}

#undef encode_ISO10163__SR__1_ProtocolVersion
int	encode_ISO10163__SR__1_ProtocolVersion(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct type_ISO10163__SR__1_ProtocolVersion *parm;
{
  return (enc_f(_ZProtocolVersionISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_ProtocolVersion
int	decode_ISO10163__SR__1_ProtocolVersion(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_ProtocolVersion **parm;
{
  return (dec_f(_ZProtocolVersionISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_ProtocolVersion
/* ARGSUSED */
int	print_ISO10163__SR__1_ProtocolVersion(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_ProtocolVersion *parm;
{
  return (prnt_f(_ZProtocolVersionISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef encode_ISO10163__SR__1_Options
int	encode_ISO10163__SR__1_Options(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct type_ISO10163__SR__1_Options *parm;
{
  return (enc_f(_ZOptionsISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_Options
int	decode_ISO10163__SR__1_Options(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_Options **parm;
{
  return (dec_f(_ZOptionsISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_Options
/* ARGSUSED */
int	print_ISO10163__SR__1_Options(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_Options *parm;
{
  return (prnt_f(_ZOptionsISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef encode_ISO10163__SR__1_PreferredMessageSize
int	encode_ISO10163__SR__1_PreferredMessageSize(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct type_ISO10163__SR__1_PreferredMessageSize *parm;
{
  return (enc_f(_ZPreferredMessageSizeISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_PreferredMessageSize
int	decode_ISO10163__SR__1_PreferredMessageSize(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_PreferredMessageSize **parm;
{
  return (dec_f(_ZPreferredMessageSizeISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_PreferredMessageSize
/* ARGSUSED */
int	print_ISO10163__SR__1_PreferredMessageSize(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_PreferredMessageSize *parm;
{
  return (prnt_f(_ZPreferredMessageSizeISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef free_ISO10163__SR__1_PreferredMessageSize
void free_ISO10163__SR__1_PreferredMessageSize(val)
struct type_ISO10163__SR__1_PreferredMessageSize *val;
{
(void) fre_obj((char *) val, _ZISO10163_SR_1_mod.md_dtab[_ZPreferredMessageSizeISO10163_SR_1], &_ZISO10163_SR_1_mod, 1);
}

#undef encode_ISO10163__SR__1_MaximumMessageSize
int	encode_ISO10163__SR__1_MaximumMessageSize(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct type_ISO10163__SR__1_MaximumMessageSize *parm;
{
  return (enc_f(_ZMaximumMessageSizeISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_MaximumMessageSize
int	decode_ISO10163__SR__1_MaximumMessageSize(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_MaximumMessageSize **parm;
{
  return (dec_f(_ZMaximumMessageSizeISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_MaximumMessageSize
/* ARGSUSED */
int	print_ISO10163__SR__1_MaximumMessageSize(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_MaximumMessageSize *parm;
{
  return (prnt_f(_ZMaximumMessageSizeISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef free_ISO10163__SR__1_MaximumMessageSize
void free_ISO10163__SR__1_MaximumMessageSize(val)
struct type_ISO10163__SR__1_MaximumMessageSize *val;
{
(void) fre_obj((char *) val, _ZISO10163_SR_1_mod.md_dtab[_ZMaximumMessageSizeISO10163_SR_1], &_ZISO10163_SR_1_mod, 1);
}

#undef encode_ISO10163__SR__1_ImplementationId
int	encode_ISO10163__SR__1_ImplementationId(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct type_ISO10163__SR__1_ImplementationId *parm;
{
  return (enc_f(_ZImplementationIdISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_ImplementationId
int	decode_ISO10163__SR__1_ImplementationId(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_ImplementationId **parm;
{
  return (dec_f(_ZImplementationIdISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_ImplementationId
/* ARGSUSED */
int	print_ISO10163__SR__1_ImplementationId(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_ImplementationId *parm;
{
  return (prnt_f(_ZImplementationIdISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef free_ISO10163__SR__1_ImplementationId
void free_ISO10163__SR__1_ImplementationId(val)
struct type_ISO10163__SR__1_ImplementationId *val;
{
(void) fre_obj((char *) val, _ZISO10163_SR_1_mod.md_dtab[_ZImplementationIdISO10163_SR_1], &_ZISO10163_SR_1_mod, 1);
}

#undef encode_ISO10163__SR__1_ImplementationName
int	encode_ISO10163__SR__1_ImplementationName(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct type_ISO10163__SR__1_ImplementationName *parm;
{
  return (enc_f(_ZImplementationNameISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_ImplementationName
int	decode_ISO10163__SR__1_ImplementationName(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_ImplementationName **parm;
{
  return (dec_f(_ZImplementationNameISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_ImplementationName
/* ARGSUSED */
int	print_ISO10163__SR__1_ImplementationName(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_ImplementationName *parm;
{
  return (prnt_f(_ZImplementationNameISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef free_ISO10163__SR__1_ImplementationName
void free_ISO10163__SR__1_ImplementationName(val)
struct type_ISO10163__SR__1_ImplementationName *val;
{
(void) fre_obj((char *) val, _ZISO10163_SR_1_mod.md_dtab[_ZImplementationNameISO10163_SR_1], &_ZISO10163_SR_1_mod, 1);
}

#undef encode_ISO10163__SR__1_ImplementationVersion
int	encode_ISO10163__SR__1_ImplementationVersion(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct type_ISO10163__SR__1_ImplementationVersion *parm;
{
  return (enc_f(_ZImplementationVersionISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_ImplementationVersion
int	decode_ISO10163__SR__1_ImplementationVersion(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_ImplementationVersion **parm;
{
  return (dec_f(_ZImplementationVersionISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_ImplementationVersion
/* ARGSUSED */
int	print_ISO10163__SR__1_ImplementationVersion(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_ImplementationVersion *parm;
{
  return (prnt_f(_ZImplementationVersionISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef free_ISO10163__SR__1_ImplementationVersion
void free_ISO10163__SR__1_ImplementationVersion(val)
struct type_ISO10163__SR__1_ImplementationVersion *val;
{
(void) fre_obj((char *) val, _ZISO10163_SR_1_mod.md_dtab[_ZImplementationVersionISO10163_SR_1], &_ZISO10163_SR_1_mod, 1);
}

#undef encode_ISO10163__SR__1_UserInformationField
int	encode_ISO10163__SR__1_UserInformationField(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct type_ISO10163__SR__1_UserInformationField *parm;
{
  return (enc_f(_ZUserInformationFieldISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_UserInformationField
int	decode_ISO10163__SR__1_UserInformationField(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_UserInformationField **parm;
{
  return (dec_f(_ZUserInformationFieldISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_UserInformationField
/* ARGSUSED */
int	print_ISO10163__SR__1_UserInformationField(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_UserInformationField *parm;
{
  return (prnt_f(_ZUserInformationFieldISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef free_ISO10163__SR__1_UserInformationField
void free_ISO10163__SR__1_UserInformationField(val)
struct type_ISO10163__SR__1_UserInformationField *val;
{
(void) fre_obj((char *) val, _ZISO10163_SR_1_mod.md_dtab[_ZUserInformationFieldISO10163_SR_1], &_ZISO10163_SR_1_mod, 1);
}

#undef encode_ISO10163__SR__1_Authentication
int	encode_ISO10163__SR__1_Authentication(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct _Authentication  *parm;
{
  return (enc_f(_ZAuthenticationISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_Authentication
int	decode_ISO10163__SR__1_Authentication(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _Authentication  **parm;
{
  return (dec_f(_ZAuthenticationISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_Authentication
/* ARGSUSED */
int	print_ISO10163__SR__1_Authentication(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _Authentication  *parm;
{
  return (prnt_f(_ZAuthenticationISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef free_ISO10163__SR__1_Authentication
void free_ISO10163__SR__1_Authentication(val)
struct _Authentication  *val;
{
(void) fre_obj((char *) val, _ZISO10163_SR_1_mod.md_dtab[_ZAuthenticationISO10163_SR_1], &_ZISO10163_SR_1_mod, 1);
}

#undef encode_ISO10163__SR__1_SearchRequest
int	encode_ISO10163__SR__1_SearchRequest(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct _SearchRequest  *parm;
{
  return (enc_f(_ZSearchRequestISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_SearchRequest
int	decode_ISO10163__SR__1_SearchRequest(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _SearchRequest  **parm;
{
  return (dec_f(_ZSearchRequestISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_SearchRequest
/* ARGSUSED */
int	print_ISO10163__SR__1_SearchRequest(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _SearchRequest  *parm;
{
  return (prnt_f(_ZSearchRequestISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef free_ISO10163__SR__1_SearchRequest
void free_ISO10163__SR__1_SearchRequest(val)
struct _SearchRequest  *val;
{
(void) fre_obj((char *) val, _ZISO10163_SR_1_mod.md_dtab[_ZSearchRequestISO10163_SR_1], &_ZISO10163_SR_1_mod, 1);
}

#undef encode_ISO10163__SR__1_Query
int	encode_ISO10163__SR__1_Query(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct _Query  *parm;
{
  return (enc_f(_ZQueryISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_Query
int	decode_ISO10163__SR__1_Query(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _Query  **parm;
{
  return (dec_f(_ZQueryISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_Query
/* ARGSUSED */
int	print_ISO10163__SR__1_Query(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _Query  *parm;
{
  return (prnt_f(_ZQueryISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef free_ISO10163__SR__1_Query
void free_ISO10163__SR__1_Query(val)
struct _Query  *val;
{
(void) fre_obj((char *) val, _ZISO10163_SR_1_mod.md_dtab[_ZQueryISO10163_SR_1], &_ZISO10163_SR_1_mod, 1);
}

#undef encode_ISO10163__SR__1_RPNQuery
int	encode_ISO10163__SR__1_RPNQuery(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct _RPNQuery  *parm;
{
  return (enc_f(_ZRPNQueryISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_RPNQuery
int	decode_ISO10163__SR__1_RPNQuery(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _RPNQuery  **parm;
{
  return (dec_f(_ZRPNQueryISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_RPNQuery
/* ARGSUSED */
int	print_ISO10163__SR__1_RPNQuery(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _RPNQuery  *parm;
{
  return (prnt_f(_ZRPNQueryISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef free_ISO10163__SR__1_RPNQuery
void free_ISO10163__SR__1_RPNQuery(val)
struct _RPNQuery  *val;
{
(void) fre_obj((char *) val, _ZISO10163_SR_1_mod.md_dtab[_ZRPNQueryISO10163_SR_1], &_ZISO10163_SR_1_mod, 1);
}

#undef encode_ISO10163__SR__1_RPNStructure
int	encode_ISO10163__SR__1_RPNStructure(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct _RPNStructure  *parm;
{
  return (enc_f(_ZRPNStructureISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_RPNStructure
int	decode_ISO10163__SR__1_RPNStructure(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _RPNStructure  **parm;
{
  return (dec_f(_ZRPNStructureISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_RPNStructure
/* ARGSUSED */
int	print_ISO10163__SR__1_RPNStructure(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _RPNStructure  *parm;
{
  return (prnt_f(_ZRPNStructureISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef free_ISO10163__SR__1_RPNStructure
void free_ISO10163__SR__1_RPNStructure(val)
struct _RPNStructure  *val;
{
(void) fre_obj((char *) val, _ZISO10163_SR_1_mod.md_dtab[_ZRPNStructureISO10163_SR_1], &_ZISO10163_SR_1_mod, 1);
}

#undef encode_ISO10163__SR__1_Operand
int	encode_ISO10163__SR__1_Operand(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct _Operand  *parm;
{
  return (enc_f(_ZOperandISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_Operand
int	decode_ISO10163__SR__1_Operand(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _Operand  **parm;
{
  return (dec_f(_ZOperandISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_Operand
/* ARGSUSED */
int	print_ISO10163__SR__1_Operand(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _Operand  *parm;
{
  return (prnt_f(_ZOperandISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef free_ISO10163__SR__1_Operand
void free_ISO10163__SR__1_Operand(val)
struct _Operand  *val;
{
(void) fre_obj((char *) val, _ZISO10163_SR_1_mod.md_dtab[_ZOperandISO10163_SR_1], &_ZISO10163_SR_1_mod, 1);
}

#undef encode_ISO10163__SR__1_AttributesPlusTerm
int	encode_ISO10163__SR__1_AttributesPlusTerm(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct _AttributesPlusTerm  *parm;
{
  return (enc_f(_ZAttributesPlusTermISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_AttributesPlusTerm
int	decode_ISO10163__SR__1_AttributesPlusTerm(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _AttributesPlusTerm  **parm;
{
  return (dec_f(_ZAttributesPlusTermISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_AttributesPlusTerm
/* ARGSUSED */
int	print_ISO10163__SR__1_AttributesPlusTerm(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _AttributesPlusTerm  *parm;
{
  return (prnt_f(_ZAttributesPlusTermISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef free_ISO10163__SR__1_AttributesPlusTerm
void free_ISO10163__SR__1_AttributesPlusTerm(val)
struct _AttributesPlusTerm  *val;
{
(void) fre_obj((char *) val, _ZISO10163_SR_1_mod.md_dtab[_ZAttributesPlusTermISO10163_SR_1], &_ZISO10163_SR_1_mod, 1);
}

#undef encode_ISO10163__SR__1_AttributeList
int	encode_ISO10163__SR__1_AttributeList(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct _AttributeList  *parm;
{
  return (enc_f(_ZAttributeListISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_AttributeList
int	decode_ISO10163__SR__1_AttributeList(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _AttributeList  **parm;
{
  return (dec_f(_ZAttributeListISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_AttributeList
/* ARGSUSED */
int	print_ISO10163__SR__1_AttributeList(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _AttributeList  *parm;
{
  return (prnt_f(_ZAttributeListISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef free_ISO10163__SR__1_AttributeList
void free_ISO10163__SR__1_AttributeList(val)
struct _AttributeList  *val;
{
(void) fre_obj((char *) val, _ZISO10163_SR_1_mod.md_dtab[_ZAttributeListISO10163_SR_1], &_ZISO10163_SR_1_mod, 1);
}

#undef encode_ISO10163__SR__1_Term
int	encode_ISO10163__SR__1_Term(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct octetString  *parm;
{
  return (enc_f(_ZTermISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_Term
int	decode_ISO10163__SR__1_Term(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct octetString  **parm;
{
  return (dec_f(_ZTermISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_Term
/* ARGSUSED */
int	print_ISO10163__SR__1_Term(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct octetString  *parm;
{
  return (prnt_f(_ZTermISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef encode_ISO10163__SR__1_Operator
int	encode_ISO10163__SR__1_Operator(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct _Operator  *parm;
{
  return (enc_f(_ZOperatorISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_Operator
int	decode_ISO10163__SR__1_Operator(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _Operator  **parm;
{
  return (dec_f(_ZOperatorISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_Operator
/* ARGSUSED */
int	print_ISO10163__SR__1_Operator(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _Operator  *parm;
{
  return (prnt_f(_ZOperatorISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef free_ISO10163__SR__1_Operator
void free_ISO10163__SR__1_Operator(val)
struct _Operator  *val;
{
(void) fre_obj((char *) val, _ZISO10163_SR_1_mod.md_dtab[_ZOperatorISO10163_SR_1], &_ZISO10163_SR_1_mod, 1);
}

#undef encode_ISO10163__SR__1_AttributeElement
int	encode_ISO10163__SR__1_AttributeElement(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct _AttributeElement  *parm;
{
  return (enc_f(_ZAttributeElementISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_AttributeElement
int	decode_ISO10163__SR__1_AttributeElement(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _AttributeElement  **parm;
{
  return (dec_f(_ZAttributeElementISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_AttributeElement
/* ARGSUSED */
int	print_ISO10163__SR__1_AttributeElement(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _AttributeElement  *parm;
{
  return (prnt_f(_ZAttributeElementISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef free_ISO10163__SR__1_AttributeElement
void free_ISO10163__SR__1_AttributeElement(val)
struct _AttributeElement  *val;
{
(void) fre_obj((char *) val, _ZISO10163_SR_1_mod.md_dtab[_ZAttributeElementISO10163_SR_1], &_ZISO10163_SR_1_mod, 1);
}

#undef encode_ISO10163__SR__1_AttributeType
int	encode_ISO10163__SR__1_AttributeType(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct type_ISO10163__SR__1_AttributeType *parm;
{
  return (enc_f(_ZAttributeTypeISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_AttributeType
int	decode_ISO10163__SR__1_AttributeType(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_AttributeType **parm;
{
  return (dec_f(_ZAttributeTypeISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_AttributeType
/* ARGSUSED */
int	print_ISO10163__SR__1_AttributeType(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_AttributeType *parm;
{
  return (prnt_f(_ZAttributeTypeISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef free_ISO10163__SR__1_AttributeType
void free_ISO10163__SR__1_AttributeType(val)
struct type_ISO10163__SR__1_AttributeType *val;
{
(void) fre_obj((char *) val, _ZISO10163_SR_1_mod.md_dtab[_ZAttributeTypeISO10163_SR_1], &_ZISO10163_SR_1_mod, 1);
}

#undef encode_ISO10163__SR__1_AttributeValue
int	encode_ISO10163__SR__1_AttributeValue(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct type_ISO10163__SR__1_AttributeValue *parm;
{
  return (enc_f(_ZAttributeValueISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_AttributeValue
int	decode_ISO10163__SR__1_AttributeValue(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_AttributeValue **parm;
{
  return (dec_f(_ZAttributeValueISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_AttributeValue
/* ARGSUSED */
int	print_ISO10163__SR__1_AttributeValue(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_AttributeValue *parm;
{
  return (prnt_f(_ZAttributeValueISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef free_ISO10163__SR__1_AttributeValue
void free_ISO10163__SR__1_AttributeValue(val)
struct type_ISO10163__SR__1_AttributeValue *val;
{
(void) fre_obj((char *) val, _ZISO10163_SR_1_mod.md_dtab[_ZAttributeValueISO10163_SR_1], &_ZISO10163_SR_1_mod, 1);
}

#undef encode_ISO10163__SR__1_SearchResponse
int	encode_ISO10163__SR__1_SearchResponse(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct _SearchResponse  *parm;
{
  return (enc_f(_ZSearchResponseISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_SearchResponse
int	decode_ISO10163__SR__1_SearchResponse(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _SearchResponse  **parm;
{
  return (dec_f(_ZSearchResponseISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_SearchResponse
/* ARGSUSED */
int	print_ISO10163__SR__1_SearchResponse(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _SearchResponse  *parm;
{
  return (prnt_f(_ZSearchResponseISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef free_ISO10163__SR__1_SearchResponse
void free_ISO10163__SR__1_SearchResponse(val)
struct _SearchResponse  *val;
{
(void) fre_obj((char *) val, _ZISO10163_SR_1_mod.md_dtab[_ZSearchResponseISO10163_SR_1], &_ZISO10163_SR_1_mod, 1);
}

#undef encode_ISO10163__SR__1_PresentRequest
int	encode_ISO10163__SR__1_PresentRequest(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct _PresentRequest  *parm;
{
  return (enc_f(_ZPresentRequestISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_PresentRequest
int	decode_ISO10163__SR__1_PresentRequest(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _PresentRequest  **parm;
{
  return (dec_f(_ZPresentRequestISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_PresentRequest
/* ARGSUSED */
int	print_ISO10163__SR__1_PresentRequest(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _PresentRequest  *parm;
{
  return (prnt_f(_ZPresentRequestISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef free_ISO10163__SR__1_PresentRequest
void free_ISO10163__SR__1_PresentRequest(val)
struct _PresentRequest  *val;
{
(void) fre_obj((char *) val, _ZISO10163_SR_1_mod.md_dtab[_ZPresentRequestISO10163_SR_1], &_ZISO10163_SR_1_mod, 1);
}

#undef encode_ISO10163__SR__1_PresentResponse
int	encode_ISO10163__SR__1_PresentResponse(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct type_ISO10163__SR__1_PresentResponse *parm;
{
  return (enc_f(_ZPresentResponseISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_PresentResponse
int	decode_ISO10163__SR__1_PresentResponse(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_PresentResponse **parm;
{
  return (dec_f(_ZPresentResponseISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_PresentResponse
/* ARGSUSED */
int	print_ISO10163__SR__1_PresentResponse(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_PresentResponse *parm;
{
  return (prnt_f(_ZPresentResponseISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef free_ISO10163__SR__1_PresentResponse
void free_ISO10163__SR__1_PresentResponse(val)
struct type_ISO10163__SR__1_PresentResponse *val;
{
(void) fre_obj((char *) val, _ZISO10163_SR_1_mod.md_dtab[_ZPresentResponseISO10163_SR_1], &_ZISO10163_SR_1_mod, 1);
}

#undef encode_ISO10163__SR__1_Records
int	encode_ISO10163__SR__1_Records(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct _Records  *parm;
{
  return (enc_f(_ZRecordsISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_Records
int	decode_ISO10163__SR__1_Records(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _Records  **parm;
{
  return (dec_f(_ZRecordsISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_Records
/* ARGSUSED */
int	print_ISO10163__SR__1_Records(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _Records  *parm;
{
  return (prnt_f(_ZRecordsISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef free_ISO10163__SR__1_Records
void free_ISO10163__SR__1_Records(val)
struct _Records  *val;
{
(void) fre_obj((char *) val, _ZISO10163_SR_1_mod.md_dtab[_ZRecordsISO10163_SR_1], &_ZISO10163_SR_1_mod, 1);
}

#undef encode_ISO10163__SR__1_NamePlusRecord
int	encode_ISO10163__SR__1_NamePlusRecord(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct _NamePlusRecord  *parm;
{
  return (enc_f(_ZNamePlusRecordISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_NamePlusRecord
int	decode_ISO10163__SR__1_NamePlusRecord(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _NamePlusRecord  **parm;
{
  return (dec_f(_ZNamePlusRecordISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_NamePlusRecord
/* ARGSUSED */
int	print_ISO10163__SR__1_NamePlusRecord(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _NamePlusRecord  *parm;
{
  return (prnt_f(_ZNamePlusRecordISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef free_ISO10163__SR__1_NamePlusRecord
void free_ISO10163__SR__1_NamePlusRecord(val)
struct _NamePlusRecord  *val;
{
(void) fre_obj((char *) val, _ZISO10163_SR_1_mod.md_dtab[_ZNamePlusRecordISO10163_SR_1], &_ZISO10163_SR_1_mod, 1);
}

#undef encode_ISO10163__SR__1_DatabaseRecord
int	encode_ISO10163__SR__1_DatabaseRecord(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct type_ISO10163__SR__1_DatabaseRecord *parm;
{
  return (enc_f(_ZDatabaseRecordISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_DatabaseRecord
int	decode_ISO10163__SR__1_DatabaseRecord(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_DatabaseRecord **parm;
{
  return (dec_f(_ZDatabaseRecordISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_DatabaseRecord
/* ARGSUSED */
int	print_ISO10163__SR__1_DatabaseRecord(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_DatabaseRecord *parm;
{
  return (prnt_f(_ZDatabaseRecordISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef free_ISO10163__SR__1_DatabaseRecord
void free_ISO10163__SR__1_DatabaseRecord(val)
struct type_ISO10163__SR__1_DatabaseRecord *val;
{
(void) fre_obj((char *) val, _ZISO10163_SR_1_mod.md_dtab[_ZDatabaseRecordISO10163_SR_1], &_ZISO10163_SR_1_mod, 1);
}

#undef encode_ISO10163__SR__1_DiagRec
int	encode_ISO10163__SR__1_DiagRec(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct _DiagRec  *parm;
{
  return (enc_f(_ZDiagRecISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_DiagRec
int	decode_ISO10163__SR__1_DiagRec(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _DiagRec  **parm;
{
  return (dec_f(_ZDiagRecISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_DiagRec
/* ARGSUSED */
int	print_ISO10163__SR__1_DiagRec(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _DiagRec  *parm;
{
  return (prnt_f(_ZDiagRecISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef free_ISO10163__SR__1_DiagRec
void free_ISO10163__SR__1_DiagRec(val)
struct _DiagRec  *val;
{
(void) fre_obj((char *) val, _ZISO10163_SR_1_mod.md_dtab[_ZDiagRecISO10163_SR_1], &_ZISO10163_SR_1_mod, 1);
}

#undef encode_ISO10163__SR__1_RecordComposition
int	encode_ISO10163__SR__1_RecordComposition(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct _RecordComposition  *parm;
{
  return (enc_f(_ZRecordCompositionISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_RecordComposition
int	decode_ISO10163__SR__1_RecordComposition(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _RecordComposition  **parm;
{
  return (dec_f(_ZRecordCompositionISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_RecordComposition
/* ARGSUSED */
int	print_ISO10163__SR__1_RecordComposition(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _RecordComposition  *parm;
{
  return (prnt_f(_ZRecordCompositionISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef free_ISO10163__SR__1_RecordComposition
void free_ISO10163__SR__1_RecordComposition(val)
struct _RecordComposition  *val;
{
(void) fre_obj((char *) val, _ZISO10163_SR_1_mod.md_dtab[_ZRecordCompositionISO10163_SR_1], &_ZISO10163_SR_1_mod, 1);
}

#undef encode_ISO10163__SR__1_RecordCompositionId
int	encode_ISO10163__SR__1_RecordCompositionId(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct type_ISO10163__SR__1_RecordCompositionId *parm;
{
  return (enc_f(_ZRecordCompositionIdISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_RecordCompositionId
int	decode_ISO10163__SR__1_RecordCompositionId(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_RecordCompositionId **parm;
{
  return (dec_f(_ZRecordCompositionIdISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_RecordCompositionId
/* ARGSUSED */
int	print_ISO10163__SR__1_RecordCompositionId(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_RecordCompositionId *parm;
{
  return (prnt_f(_ZRecordCompositionIdISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef free_ISO10163__SR__1_RecordCompositionId
void free_ISO10163__SR__1_RecordCompositionId(val)
struct type_ISO10163__SR__1_RecordCompositionId *val;
{
(void) fre_obj((char *) val, _ZISO10163_SR_1_mod.md_dtab[_ZRecordCompositionIdISO10163_SR_1], &_ZISO10163_SR_1_mod, 1);
}

#undef encode_ISO10163__SR__1_NumberOfRecordsReturned
int	encode_ISO10163__SR__1_NumberOfRecordsReturned(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct type_ISO10163__SR__1_NumberOfRecordsReturned *parm;
{
  return (enc_f(_ZNumberOfRecordsReturnedISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_NumberOfRecordsReturned
int	decode_ISO10163__SR__1_NumberOfRecordsReturned(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_NumberOfRecordsReturned **parm;
{
  return (dec_f(_ZNumberOfRecordsReturnedISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_NumberOfRecordsReturned
/* ARGSUSED */
int	print_ISO10163__SR__1_NumberOfRecordsReturned(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_NumberOfRecordsReturned *parm;
{
  return (prnt_f(_ZNumberOfRecordsReturnedISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef free_ISO10163__SR__1_NumberOfRecordsReturned
void free_ISO10163__SR__1_NumberOfRecordsReturned(val)
struct type_ISO10163__SR__1_NumberOfRecordsReturned *val;
{
(void) fre_obj((char *) val, _ZISO10163_SR_1_mod.md_dtab[_ZNumberOfRecordsReturnedISO10163_SR_1], &_ZISO10163_SR_1_mod, 1);
}

#undef encode_ISO10163__SR__1_NextResultSetPosition
int	encode_ISO10163__SR__1_NextResultSetPosition(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct type_ISO10163__SR__1_NextResultSetPosition *parm;
{
  return (enc_f(_ZNextResultSetPositionISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_NextResultSetPosition
int	decode_ISO10163__SR__1_NextResultSetPosition(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_NextResultSetPosition **parm;
{
  return (dec_f(_ZNextResultSetPositionISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_NextResultSetPosition
/* ARGSUSED */
int	print_ISO10163__SR__1_NextResultSetPosition(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_NextResultSetPosition *parm;
{
  return (prnt_f(_ZNextResultSetPositionISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef free_ISO10163__SR__1_NextResultSetPosition
void free_ISO10163__SR__1_NextResultSetPosition(val)
struct type_ISO10163__SR__1_NextResultSetPosition *val;
{
(void) fre_obj((char *) val, _ZISO10163_SR_1_mod.md_dtab[_ZNextResultSetPositionISO10163_SR_1], &_ZISO10163_SR_1_mod, 1);
}

#undef encode_ISO10163__SR__1_PresentStatus
int	encode_ISO10163__SR__1_PresentStatus(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct type_ISO10163__SR__1_PresentStatus *parm;
{
  return (enc_f(_ZPresentStatusISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_PresentStatus
int	decode_ISO10163__SR__1_PresentStatus(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_PresentStatus **parm;
{
  return (dec_f(_ZPresentStatusISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_PresentStatus
/* ARGSUSED */
int	print_ISO10163__SR__1_PresentStatus(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_PresentStatus *parm;
{
  return (prnt_f(_ZPresentStatusISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef free_ISO10163__SR__1_PresentStatus
void free_ISO10163__SR__1_PresentStatus(val)
struct type_ISO10163__SR__1_PresentStatus *val;
{
(void) fre_obj((char *) val, _ZISO10163_SR_1_mod.md_dtab[_ZPresentStatusISO10163_SR_1], &_ZISO10163_SR_1_mod, 1);
}

#undef encode_ISO10163__SR__1_PreferredRecordSyntax
int	encode_ISO10163__SR__1_PreferredRecordSyntax(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct type_ISO10163__SR__1_PreferredRecordSyntax *parm;
{
  return (enc_f(_ZPreferredRecordSyntaxISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_PreferredRecordSyntax
int	decode_ISO10163__SR__1_PreferredRecordSyntax(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_PreferredRecordSyntax **parm;
{
  return (dec_f(_ZPreferredRecordSyntaxISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_PreferredRecordSyntax
/* ARGSUSED */
int	print_ISO10163__SR__1_PreferredRecordSyntax(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_PreferredRecordSyntax *parm;
{
  return (prnt_f(_ZPreferredRecordSyntaxISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef encode_ISO10163__SR__1_DeleteResultSetRequest
int	encode_ISO10163__SR__1_DeleteResultSetRequest(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct _DeleteResultSetRequest  *parm;
{
  return (enc_f(_ZDeleteResultSetRequestISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_DeleteResultSetRequest
int	decode_ISO10163__SR__1_DeleteResultSetRequest(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _DeleteResultSetRequest  **parm;
{
  return (dec_f(_ZDeleteResultSetRequestISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_DeleteResultSetRequest
/* ARGSUSED */
int	print_ISO10163__SR__1_DeleteResultSetRequest(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _DeleteResultSetRequest  *parm;
{
  return (prnt_f(_ZDeleteResultSetRequestISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef free_ISO10163__SR__1_DeleteResultSetRequest
void free_ISO10163__SR__1_DeleteResultSetRequest(val)
struct _DeleteResultSetRequest  *val;
{
(void) fre_obj((char *) val, _ZISO10163_SR_1_mod.md_dtab[_ZDeleteResultSetRequestISO10163_SR_1], &_ZISO10163_SR_1_mod, 1);
}

#undef encode_ISO10163__SR__1_DeleteResultSetResponse
int	encode_ISO10163__SR__1_DeleteResultSetResponse(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct _DeleteResultSetResponse  *parm;
{
  return (enc_f(_ZDeleteResultSetResponseISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_DeleteResultSetResponse
int	decode_ISO10163__SR__1_DeleteResultSetResponse(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _DeleteResultSetResponse  **parm;
{
  return (dec_f(_ZDeleteResultSetResponseISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_DeleteResultSetResponse
/* ARGSUSED */
int	print_ISO10163__SR__1_DeleteResultSetResponse(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _DeleteResultSetResponse  *parm;
{
  return (prnt_f(_ZDeleteResultSetResponseISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef free_ISO10163__SR__1_DeleteResultSetResponse
void free_ISO10163__SR__1_DeleteResultSetResponse(val)
struct _DeleteResultSetResponse  *val;
{
(void) fre_obj((char *) val, _ZISO10163_SR_1_mod.md_dtab[_ZDeleteResultSetResponseISO10163_SR_1], &_ZISO10163_SR_1_mod, 1);
}

#undef encode_ISO10163__SR__1_ListStatuses
int	encode_ISO10163__SR__1_ListStatuses(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct _ListStatuses  *parm;
{
  return (enc_f(_ZListStatusesISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_ListStatuses
int	decode_ISO10163__SR__1_ListStatuses(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _ListStatuses  **parm;
{
  return (dec_f(_ZListStatusesISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_ListStatuses
/* ARGSUSED */
int	print_ISO10163__SR__1_ListStatuses(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct _ListStatuses  *parm;
{
  return (prnt_f(_ZListStatusesISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef free_ISO10163__SR__1_ListStatuses
void free_ISO10163__SR__1_ListStatuses(val)
struct _ListStatuses  *val;
{
(void) fre_obj((char *) val, _ZISO10163_SR_1_mod.md_dtab[_ZListStatusesISO10163_SR_1], &_ZISO10163_SR_1_mod, 1);
}

#undef encode_ISO10163__SR__1_DeleteSetStatus
int	encode_ISO10163__SR__1_DeleteSetStatus(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct type_ISO10163__SR__1_DeleteSetStatus *parm;
{
  return (enc_f(_ZDeleteSetStatusISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_DeleteSetStatus
int	decode_ISO10163__SR__1_DeleteSetStatus(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_DeleteSetStatus **parm;
{
  return (dec_f(_ZDeleteSetStatusISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_DeleteSetStatus
/* ARGSUSED */
int	print_ISO10163__SR__1_DeleteSetStatus(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_DeleteSetStatus *parm;
{
  return (prnt_f(_ZDeleteSetStatusISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef free_ISO10163__SR__1_DeleteSetStatus
void free_ISO10163__SR__1_DeleteSetStatus(val)
struct type_ISO10163__SR__1_DeleteSetStatus *val;
{
(void) fre_obj((char *) val, _ZISO10163_SR_1_mod.md_dtab[_ZDeleteSetStatusISO10163_SR_1], &_ZISO10163_SR_1_mod, 1);
}

#undef encode_ISO10163__SR__1_ReferenceId
int	encode_ISO10163__SR__1_ReferenceId(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct octetString  *parm;
{
  return (enc_f(_ZReferenceIdISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_ReferenceId
int	decode_ISO10163__SR__1_ReferenceId(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct octetString  **parm;
{
  return (dec_f(_ZReferenceIdISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_ReferenceId
/* ARGSUSED */
int	print_ISO10163__SR__1_ReferenceId(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct octetString  *parm;
{
  return (prnt_f(_ZReferenceIdISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef encode_ISO10163__SR__1_DatabaseName
int	encode_ISO10163__SR__1_DatabaseName(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct type_ISO10163__SR__1_DatabaseName *parm;
{
  return (enc_f(_ZDatabaseNameISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_DatabaseName
int	decode_ISO10163__SR__1_DatabaseName(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_DatabaseName **parm;
{
  return (dec_f(_ZDatabaseNameISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_DatabaseName
/* ARGSUSED */
int	print_ISO10163__SR__1_DatabaseName(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_DatabaseName *parm;
{
  return (prnt_f(_ZDatabaseNameISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef free_ISO10163__SR__1_DatabaseName
void free_ISO10163__SR__1_DatabaseName(val)
struct type_ISO10163__SR__1_DatabaseName *val;
{
(void) fre_obj((char *) val, _ZISO10163_SR_1_mod.md_dtab[_ZDatabaseNameISO10163_SR_1], &_ZISO10163_SR_1_mod, 1);
}

#undef encode_ISO10163__SR__1_ResultSetId
int	encode_ISO10163__SR__1_ResultSetId(pe, top, len, buffer, parm)
PE     *pe;
int	top,
	len;
char   *buffer;
struct type_ISO10163__SR__1_ResultSetId *parm;
{
  return (enc_f(_ZResultSetIdISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char *) parm));
}

#undef decode_ISO10163__SR__1_ResultSetId
int	decode_ISO10163__SR__1_ResultSetId(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_ResultSetId **parm;
{
  return (dec_f(_ZResultSetIdISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer,
		(char **) parm));
}

#undef print_ISO10163__SR__1_ResultSetId
/* ARGSUSED */
int	print_ISO10163__SR__1_ResultSetId(pe, top, len, buffer, parm)
PE	pe;
int	top,
       *len;
char  **buffer;
struct type_ISO10163__SR__1_ResultSetId *parm;
{
  return (prnt_f(_ZResultSetIdISO10163_SR_1, &_ZISO10163_SR_1_mod, pe, top, len, buffer));
}

#undef free_ISO10163__SR__1_ResultSetId
void free_ISO10163__SR__1_ResultSetId(val)
struct type_ISO10163__SR__1_ResultSetId *val;
{
(void) fre_obj((char *) val, _ZISO10163_SR_1_mod.md_dtab[_ZResultSetIdISO10163_SR_1], &_ZISO10163_SR_1_mod, 1);
}

#endif	/* lint||PEPSY_LINKABLE_FUNCS */
